@@ -19,19 +19,37 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "advanced-exif.h"
 
+#include <cstring>
+
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <pango/pango.h>
+
+#include <config.h>
+
+#include "compat.h"
+#include "debug.h"
+#include "dnd.h"
 #include "exif.h"
 #include "filedata.h"
 #include "history-list.h"
+#include "intl.h"
 #include "layout-util.h"
+#include "layout.h"
 #include "misc.h"
+#include "options.h"
 #include "ui-misc.h"
 #include "window.h"
-#include "dnd.h"
 
-#define ADVANCED_EXIF_DATA_COLUMN_WIDTH 200
+struct ExifData;
+struct ExifItem;
+
+enum {
+	ADVANCED_EXIF_DATA_COLUMN_WIDTH = 200
+};
 
 /*
  *-------------------------------------------------------------------
@@ -303,7 +321,8 @@ static gint advanced_exif_sort_cb(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIt
 		case EXIF_ADVCOL_FORMAT:
 		case EXIF_ADVCOL_ELEMENTS:
 			{
-			gchar *s1, *s2;
+			gchar *s1;
+			gchar *s2;
 
 			gtk_tree_model_get(model, a, n, &s1, -1);
 			gtk_tree_model_get(model, b, n, &s2, -1);
@@ -330,7 +349,7 @@ static gint advanced_exif_sort_cb(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIt
 	return ret;
 }
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 static gboolean advanced_exif_mouseclick(GtkWidget *, GdkEventButton *, gpointer data)
 {
 /* @FIXME GTK4 stub */
