@@ -19,27 +19,37 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
-#ifdef HAVE_LIBCHAMPLAIN
-#ifdef HAVE_LIBCHAMPLAIN_GTK
-
 #include "bar-gps.h"
 
+#include <cstring>
+
+#include <cairo.h>
+#include <champlain-gtk/champlain-gtk.h>
+#include <champlain/champlain.h>
+#include <clutter-gtk/clutter-gtk.h>
+#include <clutter/clutter.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <pango/pango.h>
+
+#include <config.h>
+
 #include "bar.h"
+#include "compat.h"
+#include "debug.h"
 #include "filedata.h"
+#include "intl.h"
 #include "layout.h"
+#include "main-defines.h"
 #include "metadata.h"
-#include "menu.h"
 #include "misc.h"
 #include "rcfile.h"
 #include "thumb.h"
+#include "typedefs.h"
 #include "ui-menu.h"
-#include "uri-utils.h"
 #include "ui-utildlg.h"
-
-#include <clutter-gtk/clutter-gtk.h>
-#include <champlain/champlain.h>
-#include <champlain-gtk/champlain-gtk.h>
+#include "uri-utils.h"
 
 #define MARKER_COLOUR 0x00, 0x00, 0xff, 0xff
 #define TEXT_COLOUR 0x00, 0x00, 0x00, 0xff
@@ -125,17 +135,21 @@ static void bar_pane_gps_close_save_cb(GenericDialog *, gpointer data)
 	g_list_free(pgd->geocode_list);
 }
 
- static void bar_pane_gps_dnd_receive(GtkWidget *pane, GdkDragContext *,
+static void bar_pane_gps_dnd_receive(GtkWidget *pane, GdkDragContext *,
 									  gint x, gint y,
 									  GtkSelectionData *selection_data, guint info,
 									  guint, gpointer)
 {
 	PaneGPSData *pgd;
 	GenericDialog *gd;
-	FileData *fd, *fd_found;
-	GList *work, *list;
-	gint count, geocoded_count;
-	gdouble latitude, longitude;
+	FileData *fd;
+	FileData *fd_found;
+	GList *work;
+	GList *list;
+	gint count;
+	gint geocoded_count;
+	gdouble latitude;
+	gdouble longitude;
 	GString *message;
 	gchar *location;
 	gchar **latlong;
@@ -289,15 +303,18 @@ static void bar_pane_gps_thumb_error_cb(ThumbLoader *tl, gpointer)
 static gboolean bar_pane_gps_marker_keypress_cb(GtkWidget *widget, ClutterButtonEvent *bevent, gpointer)
 {
 	FileData *fd;
-	ClutterActor *label_marker, *parent_marker;
+	ClutterActor *label_marker;
+	ClutterActor *parent_marker;
 	ClutterColor marker_colour = { MARKER_COLOUR };
 	ClutterColor text_colour = { TEXT_COLOUR };
 	ClutterColor thumb_colour = { THUMB_COLOUR };
 	gchar *current_text;
-	ClutterActor *actor, *direction;
+	ClutterActor *actor;
+	ClutterActor *direction;
 	ClutterActor *current_image;
 	GString *text;
-	gint height, width;
+	gint height;
+	gint width;
 	GdkPixbufRotation rotate;
 	gchar *altitude = nullptr;
 	ThumbLoader *tl;
@@ -327,7 +344,7 @@ static gboolean bar_pane_gps_marker_keypress_cb(GtkWidget *widget, ClutterButton
 			 * If not, call the thumb_loader to generate a thumbnail and update the marker later in the
 			 * thumb_loader callback
 			 */
-			 if (fd->thumb_pixbuf != nullptr)
+			if (fd->thumb_pixbuf != nullptr)
 				{
 				actor = gtk_clutter_texture_new();
 				gtk_clutter_texture_set_from_pixbuf(GTK_CLUTTER_TEXTURE(actor), fd->thumb_pixbuf, nullptr);
@@ -425,7 +442,8 @@ static gboolean bar_pane_gps_create_markers_cb(gpointer data)
 	gdouble longitude;
 	gdouble compass;
 	FileData *fd;
-	ClutterActor *parent_marker, *label_marker;
+	ClutterActor *parent_marker;
+	ClutterActor *label_marker;
 	ClutterActor *direction;
 	ClutterColor marker_colour = { MARKER_COLOUR };
 	ClutterColor thumb_colour = { THUMB_COLOUR };
@@ -501,7 +519,7 @@ static gboolean bar_pane_gps_create_markers_cb(gpointer data)
 		 	champlain_bounding_box_get_center(pgd->bbox, &latitude, &longitude);
 		 	champlain_view_go_to(CHAMPLAIN_VIEW(pgd->gps_view), latitude, longitude);
 		 	}
-		 else if (pgd->num_added > 1)
+		else if (pgd->num_added > 1)
 		 	{
 			champlain_view_ensure_visible(CHAMPLAIN_VIEW(pgd->gps_view), pgd->bbox, TRUE);
 			}
@@ -664,7 +682,8 @@ static void bar_pane_gps_write_config(GtkWidget *pane, GString *outstr, gint ind
 	const gchar *map_id;
 	gdouble position;
 	gint int_position;
-	gint w, h;
+	gint w;
+	gint h;
 
 	pgd = static_cast<PaneGPSData *>(g_object_get_data(G_OBJECT(pane), "pane_data"));
 	if (!pgd) return;
@@ -843,16 +862,15 @@ static void bar_pane_gps_map_centreing(PaneGPSData *pgd)
 
 	gd = generic_dialog_new(_("Map centering"),
 				"map_centering", nullptr, TRUE, nullptr, pgd);
-	generic_dialog_add_message(gd, GQ_ICON_DIALOG_INFO,
-				"Map Centering", message->str, TRUE);
-	generic_dialog_add_button(gd, GQ_ICON_OK, "OK", NULL, TRUE);
+	generic_dialog_add_message(gd, GQ_ICON_DIALOG_INFO, _("Map Centering"), message->str, TRUE);
+	generic_dialog_add_button(gd, GQ_ICON_OK, "OK", nullptr, TRUE);
 
 	gtk_widget_show(gd->dialog);
 
 	g_string_free(message, TRUE);
 }
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 static gboolean bar_pane_gps_map_keypress_cb(GtkWidget *, GdkEventButton *bevent, gpointer data)
 {
 /* @FIXME GTK4 stub */
@@ -872,12 +890,14 @@ static gboolean bar_pane_gps_map_keypress_cb(GtkWidget *, GdkEventButton *bevent
 		gtk_menu_popup_at_pointer(GTK_MENU(menu), nullptr);
 		return TRUE;
 		}
-	else if (bevent->button == MOUSE_BUTTON_MIDDLE)
+
+	if (bevent->button == MOUSE_BUTTON_MIDDLE)
 		{
 		bar_pane_gps_map_centreing(pgd);
 		return TRUE;
 		}
-	else if (bevent->button == MOUSE_BUTTON_LEFT)
+
+	if (bevent->button == MOUSE_BUTTON_LEFT)
 		{
 		clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
 		geo_coords = g_strdup_printf("%lf %lf",
@@ -891,10 +911,8 @@ static gboolean bar_pane_gps_map_keypress_cb(GtkWidget *, GdkEventButton *bevent
 
 		return TRUE;
 		}
-	else
-		{
-		return FALSE;
-		}
+
+	return FALSE;
 }
 #endif
 
@@ -922,9 +940,13 @@ GtkWidget *bar_pane_gps_new(const gchar *id, const gchar *title, const gchar *ma
             				gboolean expanded, gint height)
 {
 	PaneGPSData *pgd;
-	GtkWidget *vbox, *frame;
+	GtkWidget *vbox;
+	GtkWidget *frame;
 	GtkWidget *gpswidget;
-	GtkWidget *status, *state, *progress, *slider;
+	GtkWidget *status;
+	GtkWidget *state;
+	GtkWidget *progress;
+	GtkWidget *slider;
 	ChamplainMarkerLayer *layer;
 	ChamplainView *view;
 	const gchar *slider_list[] = {GQ_ICON_ZOOM_IN, GQ_ICON_ZOOM_OUT, nullptr};
@@ -953,7 +975,7 @@ GtkWidget *bar_pane_gps_new(const gchar *id, const gchar *title, const gchar *ma
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 
 	status = gtk_box_new(GTK_ORIENTATION_HORIZONTAL,0);
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 	slider = gtk_scale_button_new(1, 17, 1, slider_icons);
 #else
 	slider = gtk_scale_button_new(GTK_ICON_SIZE_SMALL_TOOLBAR, 1, 17, 1, slider_icons);
@@ -1077,8 +1099,10 @@ void bar_pane_gps_update_from_config(GtkWidget *pane, const gchar **attribute_na
 {
 	PaneGPSData *pgd;
 	gint zoom;
-	gint int_longitude, int_latitude;
-	gdouble longitude, latitude;
+	gint int_longitude;
+	gint int_latitude;
+	gdouble longitude;
+	gdouble latitude;
 
 	pgd = static_cast<PaneGPSData *>(g_object_get_data(G_OBJECT(pane), "pane_data"));
 	if (!pgd)
@@ -1108,13 +1132,13 @@ void bar_pane_gps_update_from_config(GtkWidget *pane, const gchar **attribute_na
 			}
 		if (READ_INT_CLAMP_FULL("longitude", int_longitude, -90000000, +90000000))
 			{
-			longitude = int_longitude / 1000000;
+			longitude = int_longitude / 1000000.0;
 			g_object_set(G_OBJECT(CHAMPLAIN_VIEW(pgd->gps_view)), "longitude", longitude, NULL);
 			continue;
 			}
 		if (READ_INT_CLAMP_FULL("latitude", int_latitude, -90000000, +90000000))
 			{
-			latitude = int_latitude / 1000000;
+			latitude = int_latitude / 1000000.0;
 			g_object_set(G_OBJECT(CHAMPLAIN_VIEW(pgd->gps_view)), "latitude", latitude, NULL);
 			continue;
 			}
@@ -1132,7 +1156,4 @@ void bar_pane_gps_update_from_config(GtkWidget *pane, const gchar **attribute_na
 	bar_update_expander(pane);
 }
 
-#endif
-#endif
-
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
