@@ -19,21 +19,32 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "bar-sort.h"
 
-#include "collect.h"
+#include <cstring>
+
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
 #include "collect-io.h"
+#include "collect.h"
+#include "compat.h"
+#include "debug.h"
 #include "editors.h"
 #include "filedata.h"
 #include "history-list.h"
-#include "layout.h"
+#include "intl.h"
 #include "layout-image.h"
+#include "layout.h"
+#include "main-defines.h"
 #include "misc.h"
+#include "options.h"
 #include "rcfile.h"
+#include "typedefs.h"
 #include "ui-bookmark.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
+#include "ui-utildlg.h"
 #include "utilops.h"
 #include "window.h"
 
@@ -433,9 +444,9 @@ static void bar_filter_help_dialog()
 	gd = generic_dialog_new(_("Sort Manager Operations"),
 				"sort_manager_operations", nullptr, TRUE, nullptr, nullptr);
 	generic_dialog_add_message(gd, GQ_ICON_DIALOG_INFO,
-				"Sort Manager Operations", _("Additional operations utilising plugins\nmay be included by setting:\n\nX-Geeqie-Filter=true\n\nin the plugin file."), TRUE);
+				_("Sort Manager Operations"), _("Additional operations utilising plugins\nmay be included by setting:\n\nX-Geeqie-Filter=true\n\nin the plugin file."), TRUE);
 	generic_dialog_add_button(gd, GQ_ICON_HELP, _("Help"), bar_filter_help_cb, TRUE);
-	generic_dialog_add_button(gd, GQ_ICON_OK, "OK", NULL, TRUE);
+	generic_dialog_add_button(gd, GQ_ICON_OK, "OK", nullptr, TRUE);
 
 	gtk_widget_show(gd->dialog);
 }
@@ -637,7 +648,8 @@ static GtkWidget *bar_sort_new(LayoutWindow *lw, SortActionType action,
 	GtkWidget *label;
 	GtkWidget *tbar;
 	GtkWidget *combo;
-	GList *editors_list, *work;
+	GList *editors_list;
+	GList *work;
 	gboolean have_filter;
 	GtkWidget *button;
 
