@@ -19,16 +19,30 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "cache-maint.h"
 
+#include <dirent.h>
+#include <sys/types.h>
+
+#include <cstdlib>
+#include <cstring>
+
+#include <glib-object.h>
+
 #include "cache-loader.h"
+#include "cache.h"
+#include "compat.h"
+#include "debug.h"
 #include "filedata.h"
+#include "intl.h"
 #include "layout.h"
+#include "main-defines.h"
+#include "main.h"
 #include "misc.h"
+#include "options.h"
 #include "pixbuf-util.h"
-#include "thumb.h"
 #include "thumb-standard.h"
+#include "thumb.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
 #include "ui-tabcomp.h"
@@ -51,7 +65,9 @@ struct CMData
 	gboolean remote;
 };
 
-#define PURGE_DIALOG_WIDTH 400
+enum {
+	PURGE_DIALOG_WIDTH = 400
+};
 
 /*
  *-----------------------------------------------------------------------------
@@ -765,7 +781,7 @@ static gboolean cache_manager_render_file(CacheOpsData *cd)
 
 		return (!success);
 		}
-	else if (cd->list_dir)
+	if (cd->list_dir)
 		{
 		FileData *fd;
 
@@ -1167,7 +1183,7 @@ static void cache_manager_standard_process(GtkWidget *widget, gboolean clear)
 						    cache_manager_standard_clean_stop_cb, FALSE);
 	gtk_widget_set_sensitive(cd->button_stop, FALSE);
 
-	generic_dialog_add_message(cd->gd, icon_name, msg, NULL, FALSE);
+	generic_dialog_add_message(cd->gd, icon_name, msg, nullptr, FALSE);
 
 	cd->progress = gtk_progress_bar_new();
 	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(cd->progress), _("click start to begin"));
@@ -1434,7 +1450,7 @@ static gboolean cache_manager_sim_file(CacheOpsData *cd)
 
 		return FALSE;
 		}
-	else if (cd->list_dir)
+	if (cd->list_dir)
 		{
 		FileData *fd;
 
