@@ -22,6 +22,11 @@
 #ifndef CACHE_MAINT_H
 #define CACHE_MAINT_H
 
+#include <glib.h>
+#include <gtk/gtk.h>
+
+#include "typedefs.h"
+
 struct FileData;
 
 void cache_maintain_home(gboolean metadata, gboolean clear, GtkWidget *parent);
