@@ -19,16 +19,29 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "cache.h"
 
+#include <sys/stat.h>
+#include <unistd.h>
+#include <utime.h>
+
+#include <cerrno>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+
+#include <config.h>
+
+#include "debug.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "md5-util.h"
+#include "options.h"
 #include "secure-save.h"
+#include "similar.h"
 #include "thumb-standard.h"
 #include "ui-fileops.h"
 
-#include <utime.h>
-
 
 /**
  * @file
@@ -115,7 +128,8 @@ static gboolean cache_sim_write_md5sum(SecureSaveInfo *ssi, CacheData *cd)
 
 static gboolean cache_sim_write_similarity(SecureSaveInfo *ssi, CacheData *cd)
 {
-	guint x, y;
+	guint x;
+	guint y;
 	guint8 buf[3 * 32];
 
 	if (!cd || !cd->similarity || !cd->sim || !cd->sim->filled) return FALSE;
@@ -200,7 +214,7 @@ static gboolean cache_sim_read_skipline(FILE *f, gint s)
 	return FALSE;
 }
 
-static gboolean cache_sim_read_comment(FILE *f, gchar *buf, gint s, CacheData *cd)
+static gboolean cache_sim_read_comment(FILE *f, const gchar *buf, gint s, CacheData *cd)
 {
 	if (!f || !buf || !cd) return FALSE;
 
@@ -220,7 +234,8 @@ static gboolean cache_sim_read_dimensions(FILE *f, gchar *buf, gint s, CacheData
 		gchar b;
 		gchar buf[1024];
 		gsize p = 0;
-		gint w, h;
+		gint w;
+		gint h;
 
 		b = 'X';
 		while (b != '[')
@@ -342,7 +357,8 @@ static gboolean cache_sim_read_similarity(FILE *f, gchar *buf, gint s, CacheData
 		gchar b;
 		guint8 pixel_buf[3];
 		ImageSimilarityData *sd;
-		gint x, y;
+		gint x;
+		gint y;
 
 		b = 'X';
 		while (b != '=')
@@ -393,7 +409,9 @@ static gboolean cache_sim_read_similarity(FILE *f, gchar *buf, gint s, CacheData
 	return FALSE;
 }
 
-#define CACHE_LOAD_LINE_NOISE 8
+enum {
+	CACHE_LOAD_LINE_NOISE = 8
+};
 
 CacheData *cache_sim_data_load(const gchar *path)
 {
@@ -494,7 +512,7 @@ void cache_sim_data_set_date_unused(CacheData *cd, time_t date)
 }
 #pragma GCC diagnostic pop
 
-void cache_sim_data_set_md5sum(CacheData *cd, guchar digest[16])
+void cache_sim_data_set_md5sum(CacheData *cd, const guchar digest[16])
 {
 	gint i;
 
