@@ -17,10 +17,16 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "cellrenderericon.h"
 
-#define FIXED_ICON_SIZE_MAX 512
+#include <cstddef>
+
+#include <cairo.h>
+#include <gdk/gdk.h>
+
+enum {
+	FIXED_ICON_SIZE_MAX = 512
+};
 
 
 static void gqv_cell_renderer_icon_get_property(GObject		*object,
@@ -311,9 +317,9 @@ gqv_cell_renderer_icon_get_property(GObject	*object,
 		{
 		GdkRGBA color;
 
-		color.red = cellicon->background.red / 65535;
-		color.green = cellicon->background.green / 65535;
-		color.blue = cellicon->background.blue / 65535;
+		color.red = cellicon->background.red / 65535.0;
+		color.green = cellicon->background.green / 65535.0;
+		color.blue = cellicon->background.blue / 65535.0;
 
 		g_value_set_boxed(value, &color);
 		}
@@ -322,9 +328,9 @@ gqv_cell_renderer_icon_get_property(GObject	*object,
 		{
 		GdkRGBA color;
 
-		color.red = cellicon->foreground.red / 65535;
-		color.green = cellicon->foreground.green / 65535;
-		color.blue = cellicon->foreground.blue / 65535;
+		color.red = cellicon->foreground.red / 65535.0;
+		color.green = cellicon->foreground.green / 65535.0;
+		color.blue = cellicon->foreground.blue / 65535.0;
 
 		g_value_set_boxed(value, &color);
 		}
@@ -552,8 +558,10 @@ static void gqv_cell_renderer_icon_get_size(GtkCellRenderer    *cell,
 	auto cellicon = reinterpret_cast<GQvCellRendererIcon *>(cell);
 	gint calc_width;
 	gint calc_height;
-	gint xpad, ypad;
-	gfloat xalign, yalign;
+	gint xpad;
+	gint ypad;
+	gfloat xalign;
+	gfloat yalign;
 
 	gtk_cell_renderer_get_padding(cell, &xpad, &ypad);
 	gtk_cell_renderer_get_alignment(cell, &xalign, &yalign);
@@ -633,7 +641,8 @@ static void gqv_cell_renderer_icon_render(GtkCellRenderer *cell,
 	const gchar *text;
 	GdkRectangle cell_rect;
 	GtkStateFlags state;
-	gint xpad, ypad;
+	gint xpad;
+	gint ypad;
 
 
 	pixbuf = cellicon->pixbuf;
@@ -750,7 +759,7 @@ static void gqv_cell_renderer_icon_render(GtkCellRenderer *cell,
 				cairo_save (cr);
 
 				cairo_rectangle(cr,
-						pix_rect.x + i * TOGGLE_SPACING + (TOGGLE_WIDTH - TOGGLE_SPACING) / 2,
+						pix_rect.x + i * TOGGLE_SPACING + (TOGGLE_WIDTH - TOGGLE_SPACING) / 2.0,
 						pix_rect.y,
 						TOGGLE_WIDTH, TOGGLE_WIDTH);
 				cairo_clip (cr);
@@ -765,19 +774,19 @@ static void gqv_cell_renderer_icon_render(GtkCellRenderer *cell,
 				if (state & GTK_STATE_FLAG_CHECKED)
 					{
 					gtk_render_check(context, cr,
-						pix_rect.x + i * TOGGLE_SPACING + (TOGGLE_WIDTH - TOGGLE_SPACING) / 2,
+						pix_rect.x + i * TOGGLE_SPACING + (TOGGLE_WIDTH - TOGGLE_SPACING) / 2.0,
 						pix_rect.y,
 						TOGGLE_WIDTH, TOGGLE_WIDTH);
 					}
 				gtk_render_frame(context, cr,
-					 pix_rect.x + i * TOGGLE_SPACING + (TOGGLE_WIDTH - TOGGLE_SPACING) / 2,
+					 pix_rect.x + i * TOGGLE_SPACING + (TOGGLE_WIDTH - TOGGLE_SPACING) / 2.0,
 					 pix_rect.y,
 					 TOGGLE_WIDTH, TOGGLE_WIDTH);
 
 				if (cellicon->focused && gtk_widget_has_focus(widget))
 					{
 					gtk_render_focus(context, cr,
-						pix_rect.x + i * TOGGLE_SPACING + (TOGGLE_WIDTH - TOGGLE_SPACING) / 2,
+						pix_rect.x + i * TOGGLE_SPACING + (TOGGLE_WIDTH - TOGGLE_SPACING) / 2.0,
 						pix_rect.y, TOGGLE_WIDTH, TOGGLE_WIDTH);
 					}
 				gtk_style_context_restore(context);
@@ -806,7 +815,8 @@ static gboolean gqv_cell_renderer_icon_activate(GtkCellRenderer      *cell,
 		GdkRectangle rect;
 		GdkRectangle cell_rect;
 		gint i;
-		gint xpad, ypad;
+		gint xpad;
+		gint ypad;
 
 		gtk_cell_renderer_get_padding(cell, &xpad, &ypad);
 
