@@ -19,26 +19,42 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "collect.h"
 
+#include <sys/stat.h>
+
+#include <cstdlib>
+#include <cstring>
+#include <ctime>
+
+#include <glib-object.h>
+
 #include "collect-dlg.h"
 #include "collect-io.h"
 #include "collect-table.h"
+#include "compat.h"
+#include "debug.h"
 #include "filedata.h"
 #include "img-view.h"
+#include "intl.h"
 #include "layout-image.h"
 #include "layout-util.h"
+#include "layout.h"
+#include "main-defines.h"
 #include "misc.h"
+#include "options.h"
 #include "pixbuf-util.h"
 #include "print.h"
 #include "ui-fileops.h"
 #include "ui-tree-edit.h"
+#include "ui-utildlg.h"
 #include "utilops.h"
 #include "window.h"
 
-#define COLLECT_DEF_WIDTH 440
-#define COLLECT_DEF_HEIGHT 450
+enum {
+	COLLECT_DEF_WIDTH = 440,
+	COLLECT_DEF_HEIGHT = 450
+};
 
 /**
  *  list of paths to collections */
@@ -180,8 +196,8 @@ static gint collection_list_sort_cb(gconstpointer a, gconstpointer b)
 
 	if (options->file_sort.case_sensitive)
 		return strcmp(cia->fd->collate_key_name, cib->fd->collate_key_name);
-	else
-		return strcmp(cia->fd->collate_key_name_nocase, cib->fd->collate_key_name_nocase);
+
+	return strcmp(cia->fd->collate_key_name_nocase, cib->fd->collate_key_name_nocase);
 }
 
 GList *collection_list_sort(GList *list, SortType method)
@@ -195,9 +211,12 @@ GList *collection_list_sort(GList *list, SortType method)
 
 GList *collection_list_randomize(GList *list)
 {
-	guint random, length, i;
+	guint random;
+	guint length;
+	guint i;
 	gpointer tmp;
-	GList *nlist, *olist;
+	GList *nlist;
+	GList *olist;
 
 	length = g_list_length(list);
 	if (!length) return nullptr;
@@ -575,8 +594,8 @@ CollectionData *collection_from_dnd_data(const gchar *data, GList **list, GList
 		while (*ptr != '\n' && *ptr != '\0') ptr++;
 		if (*ptr == '\0')
 			break;
-		else
-			while (*ptr == '\n') ptr++;
+
+		while (*ptr == '\n') ptr++;
 
 		info = static_cast<CollectInfo *>(g_list_nth_data(cd->list, item_number));
 		if (!info) continue;
@@ -1191,7 +1210,8 @@ static void collection_close_save_cb(GenericDialog *gd, gpointer data)
 		collection_dialog_save_close(cw->cd);
 		return;
 		}
-	else if (!collection_save(cw->cd, cw->cd->path))
+
+	if (!collection_save(cw->cd, cw->cd->path))
 		{
 		gchar *buf;
 		buf = g_strdup_printf(_("Failed to save the collection:\n%s"), cw->cd->path);
