@@ -19,17 +19,34 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "editors.h"
 
+#include <dirent.h>
+#include <unistd.h>
+
+#include <cstdlib>
+#include <cstring>
+
+#include <glib-object.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "filedata.h"
 #include "filefilter.h"
+#include "intl.h"
+#include "main-defines.h"
+#include "main.h"
+#include "options.h"
 #include "pixbuf-util.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
+#include "ui-utildlg.h"
 #include "utilops.h"
 
-#define EDITOR_WINDOW_WIDTH 500
-#define EDITOR_WINDOW_HEIGHT 300
+enum {
+	EDITOR_WINDOW_WIDTH = 500,
+	EDITOR_WINDOW_HEIGHT = 300
+};
 
 
 
@@ -174,7 +191,9 @@ gboolean editor_read_desktop_file(const gchar *path)
 	gchar *extensions;
 	gchar *type;
 	const gchar *key = filename_from_path(path);
-	gchar **categories, **only_show_in, **not_show_in;
+	gchar **categories;
+	gchar **only_show_in;
+	gchar **not_show_in;
 	gchar *try_exec;
 	GtkTreeIter iter;
 	gboolean category_geeqie = FALSE;
@@ -1439,9 +1458,9 @@ const gchar *editor_get_error_str(EditorFlags flags)
 #pragma GCC diagnostic ignored "-Wunused-function"
 const gchar *editor_get_name_unused(const gchar *key)
 {
-	EditorDescription *editor = static_cast<EditorDescription *>(g_hash_table_lookup(editors, key));
+	auto *editor = static_cast<EditorDescription *>(g_hash_table_lookup(editors, key));
 
-	if (!editor) return NULL;
+	if (!editor) return nullptr;
 
 	return editor->name;
 }
