@@ -22,6 +22,9 @@
 #ifndef EDITORS_H
 #define EDITORS_H
 
+#include <glib.h>
+#include <gtk/gtk.h>
+
 struct FileData;
 
 enum EditorFlags {
