@@ -22,6 +22,15 @@
 #ifndef FILEDATA_H
 #define FILEDATA_H
 
+#include <sys/types.h>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib.h>
+
+#include <config.h>
+
+#include "typedefs.h"
+
 struct ExifData;
 struct HistMap;
 
