@@ -19,16 +19,23 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "fullscreen.h"
 
 #include <algorithm>
+#include <cstddef>
 #include <string>
 #include <vector>
 
-#include "image.h"
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "image-load.h"
+#include "image.h"
+#include "intl.h"
 #include "misc.h"
+#include "options.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
 #include "window.h"
