@@ -18,21 +18,26 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "histogram.h"
 
-#include "pixbuf-util.h"
-#include "filedata.h"
-
 #include <cmath>
 
+#include <glib-object.h>
+
+#include "debug.h"
+#include "filedata.h"
+#include "intl.h"
+#include "pixbuf-util.h"
+
 /*
  *----------------------------------------------------------------------------
  * image histogram
  *----------------------------------------------------------------------------
  */
 
-#define HISTMAP_SIZE 256
+enum {
+	HISTMAP_SIZE = 256
+};
 
 struct HistMap {
 	gulong r[HISTMAP_SIZE];
@@ -152,7 +157,14 @@ void histmap_free(HistMap *histmap)
 
 static gboolean histmap_read(HistMap *histmap, gboolean whole)
 {
-	gint w, h, i, j, srs, has_alpha, step, end_line;
+	gint w;
+	gint h;
+	gint i;
+	gint j;
+	gint srs;
+	gint has_alpha;
+	gint step;
+	gint end_line;
 	guchar *s_pix;
 	GdkPixbuf *imgpixbuf = histmap->pixbuf;
 
