@@ -25,17 +25,25 @@
  * LibRaw seems to be slower than exiv2, so let exiv2 have priority.
  */
 
-#include "main.h"
-
-#include "filedata.h"
-#include "filefilter.h"
-#include "image-load.h"
 #include "image-load-libraw.h"
 
-#ifdef HAVE_RAW
+#include <config.h>
+
+#include "image-load.h"
+
+#if HAVE_RAW
+
+#include <fcntl.h>
+#include <sys/mman.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 #include <libraw/libraw.h>
-#include <sys/mman.h>
+
+#include "debug.h"
+#include "filedata.h"
+#include "filefilter.h"
+#include "typedefs.h"
 
 struct UnmapData
 {
@@ -47,7 +55,7 @@ struct UnmapData
 
 static GList *libraw_unmap_list = nullptr;
 
-void libraw_free_preview(guchar *buf)
+void libraw_free_preview(const guchar *buf)
 {
 	GList *work = libraw_unmap_list;
 
@@ -135,7 +143,7 @@ guchar *libraw_get_preview(ImageLoader *il, guint *data_len)
 
 #else /* !define HAVE_RAW */
 
-void libraw_free_preview(guchar *)
+void libraw_free_preview(const guchar *)
 {
 }
 
