@@ -19,22 +19,35 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "image-overlay.h"
 
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
+#include <pango/pango.h>
+
 #include "collect.h"
+#include "debug.h"
 #include "filedata.h"
 #include "histogram.h"
-#include "image.h"
 #include "image-load.h"
+#include "image.h"
 #include "img-view.h"
+#include "intl.h"
 #include "layout.h"
+#include "main-defines.h"
+#include "options.h"
 #include "osd.h"
 #include "pixbuf-renderer.h"
 #include "pixbuf-util.h"
 #include "slideshow.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
 
+struct HistMap;
+
 /*
  *----------------------------------------------------------------------------
  * image overlay
@@ -86,10 +99,14 @@ static OSDIcon osd_icons[] = {
 
 #define OSD_DATA "overlay-data"
 
-#define IMAGE_OSD_DEFAULT_DURATION 30
+enum {
+	IMAGE_OSD_DEFAULT_DURATION = 30
+};
 
-#define HISTOGRAM_HEIGHT 140
-#define HISTOGRAM_WIDTH  256
+enum {
+	HISTOGRAM_HEIGHT = 140,
+	HISTOGRAM_WIDTH =  256
+};
 
 static void image_osd_timer_schedule(OverlayStateData *osd);
 
@@ -210,23 +227,22 @@ void image_osd_toggle(ImageWindow *imd)
 		image_osd_set(imd, static_cast<OsdShowFlags>(OSD_SHOW_INFO | OSD_SHOW_STATUS));
 		return;
 		}
+
+	if (show & OSD_SHOW_HISTOGRAM)
+		{
+		image_osd_set(imd, OSD_SHOW_NOTHING);
+		}
 	else
 		{
-		if (show & OSD_SHOW_HISTOGRAM)
-			{
-			image_osd_set(imd, OSD_SHOW_NOTHING);
-			}
-		else
-			{
-			image_osd_set(imd, static_cast<OsdShowFlags>(show | OSD_SHOW_HISTOGRAM));
-			}
+		image_osd_set(imd, static_cast<OsdShowFlags>(show | OSD_SHOW_HISTOGRAM));
 		}
 }
 
 static GdkPixbuf *image_osd_info_render(OverlayStateData *osd)
 {
 	GdkPixbuf *pixbuf = nullptr;
-	gint width, height;
+	gint width;
+	gint height;
 	PangoLayout *layout;
 	const gchar *name;
 	gchar *text;
@@ -241,7 +257,8 @@ static GdkPixbuf *image_osd_info_render(OverlayStateData *osd)
 	name = image_get_name(imd);
 	if (name)
 		{
-		gint n, t;
+		gint n;
+		gint t;
 		CollectionData *cd;
 		CollectInfo *info;
 		GHashTable *vars;
@@ -308,7 +325,8 @@ static GdkPixbuf *image_osd_info_render(OverlayStateData *osd)
 
 		if (!imd->unknown)
 			{
-			gint w, h;
+			gint w;
+			gint h;
 			GdkPixbuf *load_pixbuf = image_loader_get_pixbuf(imd->il);
 
 			if (imd->delay_flip &&
@@ -866,7 +884,8 @@ Histogram *image_osd_get_histogram(ImageWindow *imd)
 
 void image_osd_copy_status(ImageWindow *src, ImageWindow *dest)
 {
-	Histogram *h_src, *h_dest;
+	Histogram *h_src;
+	Histogram *h_dest;
 	image_osd_set(dest, image_osd_get(src));
 
 	h_src = image_osd_get_histogram(src);
