@@ -19,24 +19,36 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "image.h"
 
+#include <cmath>
+#include <cstring>
+
+#include <cairo.h>
+#include <glib-object.h>
+
 #include "collect-table.h"
+#include "collect.h"
 #include "color-man.h"
+#include "compat.h"
+#include "debug.h"
 #include "exif.h"
-#include "metadata.h"
+#include "filecache.h"
+#include "filedata.h"
 #include "history-list.h"
 #include "image-load.h"
-#include "layout.h"
+#include "intl.h"
 #include "layout-image.h"
+#include "layout.h"
+#include "metadata.h"
+#include "options.h"
 #include "pixbuf-renderer.h"
 #include "pixbuf-util.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
-#include "filecache.h"
 
-#include <cmath>
+struct ExifData;
+struct FileCacheData;
 
 static GList *image_list = nullptr;
 
@@ -141,7 +153,8 @@ static void image_press_cb(PixbufRenderer *pr, GdkEventButton *event, gpointer d
 {
 	auto imd = static_cast<ImageWindow *>(data);
 	LayoutWindow *lw;
-	gint x_pixel, y_pixel;
+	gint x_pixel;
+	gint y_pixel;
 
 	if(options->draw_rectangle)
 		{
@@ -198,18 +211,21 @@ static void image_release_cb(PixbufRenderer *, GdkEventButton *event, gpointer d
 		layout_valid(&lw);
 		}
 
-	defined_mouse_buttons(NULL, event, lw);
+	defined_mouse_buttons(nullptr, event, lw);
 }
 
 static void image_drag_cb(PixbufRenderer *pr, GdkEventMotion *event, gpointer data)
 {
 	auto imd = static_cast<ImageWindow *>(data);
-	gint width, height;
+	gint width;
+	gint height;
 	gint rect_width;
 	gint rect_height;
 	GdkPixbuf *rect_pixbuf;
-	gint x_pixel, y_pixel;
-	gint image_x_pixel, image_y_pixel;
+	gint x_pixel;
+	gint y_pixel;
+	gint image_x_pixel;
+	gint image_y_pixel;
 
 	if (options->draw_rectangle)
 		{
@@ -985,7 +1001,7 @@ static gboolean image_read_ahead_check(ImageWindow *imd)
 		imd->read_ahead_fd = nullptr;
 		return TRUE;
 		}
-	else if (imd->read_ahead_fd->pixbuf)
+	if (imd->read_ahead_fd->pixbuf)
 		{
 		image_change_pixbuf(imd, imd->read_ahead_fd->pixbuf, image_zoom_get(imd), FALSE);
 
@@ -1216,11 +1232,9 @@ static gboolean image_scroll_cb(GtkWidget *, GdkEventScroll *event, gpointer dat
 				}
 			return TRUE;
 			}
-		else
-			{
-			imd->func_scroll(imd, event, imd->data_scroll);
-			return TRUE;
-			}
+
+		imd->func_scroll(imd, event, imd->data_scroll);
+		return TRUE;
 		}
 
 	return FALSE;
@@ -1694,7 +1708,8 @@ void image_zoom_set_fill_geometry(ImageWindow *imd, gboolean vertical)
 {
 	PixbufRenderer *pr;
 	gdouble zoom;
-	gint width, height;
+	gint width;
+	gint height;
 
 	pr = reinterpret_cast<PixbufRenderer *>(imd->pr);
 
@@ -2162,7 +2177,7 @@ void image_set_frame(ImageWindow *imd, gboolean frame)
 		if (imd->frame)
 			{
 			gtk_container_remove(GTK_CONTAINER(imd->frame), imd->pr);
-			g_object_unref(imd->frame);
+			gtk_container_remove(GTK_CONTAINER(imd->widget), imd->frame);
 			imd->frame = nullptr;
 			}
         	gq_gtk_box_pack_start(GTK_BOX(imd->widget), imd->pr, TRUE, TRUE, 0);
