@@ -19,33 +19,50 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "layout-image.h"
 
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <gio/gio.h>
+#include <glib-object.h>
+#include <pango/pango.h>
+
+#include <config.h>
+
+#include "archives.h"
 #include "collect.h"
+#include "debug.h"
 #include "dnd.h"
 #include "editors.h"
 #include "exif.h"
 #include "filedata.h"
 #include "fullscreen.h"
 #include "history-list.h"
-#include "image.h"
 #include "image-overlay.h"
+#include "image.h"
 #include "img-view.h"
+#include "intl.h"
 #include "layout-util.h"
+#include "layout.h"
+#include "main-defines.h"
 #include "menu.h"
 #include "metadata.h"
 #include "misc.h"
-#include "pixbuf-util.h"
+#include "options.h"
 #include "pixbuf-renderer.h"
 #include "slideshow.h"
 #include "ui-fileops.h"
 #include "ui-menu.h"
+#include "ui-utildlg.h"
 #include "uri-utils.h"
 #include "utilops.h"
 #include "view-file.h"
 
-#define FILE_COLUMN_POINTER 0
+enum {
+	FILE_COLUMN_POINTER = 0
+};
 
 static GtkWidget *layout_image_pop_menu(LayoutWindow *lw);
 static void layout_image_set_buttons(LayoutWindow *lw);
@@ -595,7 +612,7 @@ static void li_pop_menu_copy_path_unquoted_cb(GtkWidget *, gpointer data)
 	file_util_copy_path_to_clipboard(layout_image_get_fd(lw), FALSE);
 }
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 static void li_pop_menu_copy_image_cb(GtkWidget *, gpointer data)
 {
 /* @FIXME GTK4 stub */
@@ -1426,7 +1443,7 @@ const gchar *layout_image_get_path(LayoutWindow *lw)
 #pragma GCC diagnostic ignored "-Wunused-function"
 const gchar *layout_image_get_name_unused(LayoutWindow *lw)
 {
-	if (!layout_valid(&lw)) return NULL;
+	if (!layout_valid(&lw)) return nullptr;
 
 	return image_get_name(lw->image);
 }
@@ -2009,7 +2026,8 @@ static void layout_image_drag_cb(ImageWindow *imd, GdkEventMotion *event, gdoubl
 {
 	gint i;
 	auto lw = static_cast<LayoutWindow *>(data);
-	gdouble sx, sy;
+	gdouble sx;
+	gdouble sy;
 
 	if (lw->full_screen && lw->image != lw->full_screen->imd &&
 	    imd != lw->full_screen->imd)
@@ -2119,8 +2137,10 @@ static gint num_length(gint num)
 void layout_status_update_pixel_cb(PixbufRenderer *pr, gpointer data)
 {
 	auto lw = static_cast<LayoutWindow *>(data);
-	gint x_pixel, y_pixel;
-	gint width, height;
+	gint x_pixel;
+	gint y_pixel;
+	gint width;
+	gint height;
 	gchar *text;
 	PangoAttrList *attrs;
 
@@ -2134,7 +2154,9 @@ void layout_status_update_pixel_cb(PixbufRenderer *pr, gpointer data)
 
 	if(x_pixel >= 0 && y_pixel >= 0)
 		{
-		gint r_mouse, g_mouse, b_mouse;
+		gint r_mouse;
+		gint g_mouse;
+		gint b_mouse;
 
 		pixbuf_renderer_get_pixel_colors(pr, x_pixel, y_pixel,
 						 &r_mouse, &g_mouse, &b_mouse);
@@ -2305,7 +2327,8 @@ static void layout_image_setup_split_common(LayoutWindow *lw, gint n)
 
 			if (img_fd)
 				{
-				gdouble sx, sy;
+				gdouble sx;
+				gdouble sy;
 				image_change_fd(lw->split_images[i], img_fd, zoom);
 				image_get_scroll_center(lw->image, &sx, &sy);
 				image_set_scroll_center(lw->split_images[i], sx, sy);
