@@ -18,15 +18,27 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "logwindow.h"
 
 #include <algorithm>
+#include <cstring>
 #include <deque>
 #include <string>
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
+
+#include <config.h>
+
+#include "compat.h"
+#include "debug.h"
+#include "intl.h"
 #include "layout.h"
+#include "main-defines.h"
 #include "misc.h"
+#include "options.h"
 #include "ui-misc.h"
 #include "window.h"
 
@@ -386,8 +398,7 @@ static LogWindow *log_window_create(LayoutWindow *lw)
 	gq_gtk_container_add(GTK_WIDGET(window), win_vbox);
 	gtk_widget_show(win_vbox);
 
-	gtk_window_resize(GTK_WINDOW(window), lw->options.log_window.w,
-											lw->options.log_window.h);
+	gtk_window_resize(GTK_WINDOW(window), lw->options.log_window.width, lw->options.log_window.height);
 	gq_gtk_window_move(GTK_WINDOW(window), lw->options.log_window.x, lw->options.log_window.y);
 
 	g_signal_connect(G_OBJECT(window), "delete_event",
@@ -450,7 +461,7 @@ static LogWindow *log_window_create(LayoutWindow *lw)
 	gtk_widget_show_all(logwin->wrap);
 
 	logwin->timer_data = gtk_toggle_button_new();
-	label = gtk_label_new("Timer");
+	label = gtk_label_new(_("Timer"));
 	gtk_widget_set_tooltip_text(GTK_WIDGET(logwin->timer_data), _("Enable timer data"));
 	gq_gtk_container_add(GTK_WIDGET(logwin->timer_data), label) ;
 	gq_gtk_box_pack_start(GTK_BOX(hbox),logwin->timer_data, FALSE, FALSE, 0) ;
@@ -635,7 +646,8 @@ void log_window_append(const gchar *str, LogType type)
 
 	if (options->log_window_lines > 0 && logwindow->lines >= options->log_window_lines)
 		{
-		GtkTextIter start, end;
+		GtkTextIter start;
+		GtkTextIter end;
 
 		gtk_text_buffer_get_start_iter(buffer, &start);
 		end = start;
