@@ -19,20 +19,34 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <clocale>
-
-#include "main.h"
 #include "metadata.h"
 
+#include <unistd.h>
+
+#include <clocale>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+
+#include <glib-object.h>
+
+#include <config.h>
+
 #include "cache.h"
+#include "debug.h"
 #include "exif.h"
 #include "filedata.h"
+#include "intl.h"
+#include "layout-util.h"
+#include "main-defines.h"
 #include "misc.h"
+#include "options.h"
+#include "rcfile.h"
 #include "secure-save.h"
 #include "ui-fileops.h"
 #include "utilops.h"
-#include "layout-util.h"
-#include "rcfile.h"
+
+struct ExifData;
 
 enum MetadataKey {
 	MK_NONE,
@@ -235,7 +249,7 @@ gboolean metadata_write_queue_remove_list_unused(GList *list)
 	work = list;
 	while (work)
 		{
-		FileData *fd = static_cast<FileData *>(work->data);
+		auto *fd = static_cast<FileData *>(work->data);
 		work = work->next;
 		ret = ret && metadata_write_queue_remove(fd);
 		}
@@ -606,7 +620,7 @@ static void metadata_legacy_delete(FileData *fd, const gchar *except)
 		g_free(metadata_path);
 		}
 
-#ifdef HAVE_EXIV2
+#if HAVE_EXIV2
 	/* without exiv2: do not delete xmp metadata because we are not able to convert it,
 	   just ignore it */
 	metadata_path = cache_find_location(CACHE_TYPE_XMP_METADATA, fd->path);
@@ -713,7 +727,7 @@ GList *metadata_read_list(FileData *fd, const gchar *key, MetadataFormat format)
 		{
 	        return g_list_append(nullptr, metadata_file_info(fd, key, format));
 		}
-#ifdef HAVE_LUA
+#if HAVE_LUA
 	else if (strncmp(key, "lua.", 4) == 0)
 		{
 		return g_list_append(nullptr, metadata_lua_info(fd, key, format));
@@ -773,7 +787,9 @@ gdouble metadata_read_GPS_coord(FileData *fd, const gchar *key, gdouble fallback
 {
 	gdouble coord;
 	gchar *endptr;
-	gdouble deg, min, sec;
+	gdouble deg;
+	gdouble min;
+	gdouble sec;
 	gboolean ok = FALSE;
 	gchar *string = metadata_read_string(fd, key, METADATA_PLAIN);
 	if (!string) return fallback;
@@ -845,14 +861,12 @@ gboolean metadata_append_string(FileData *fd, const gchar *key, const char *valu
 		{
 		return metadata_write_string(fd, key, value);
 		}
-	else
-		{
-		gchar *new_string = g_strconcat(str, value, NULL);
-		gboolean ret = metadata_write_string(fd, key, new_string);
-		g_free(str);
-		g_free(new_string);
-		return ret;
-		}
+
+	gchar *new_string = g_strconcat(str, value, NULL);
+	gboolean ret = metadata_write_string(fd, key, new_string);
+	g_free(str);
+	g_free(new_string);
+	return ret;
 }
 
 gboolean metadata_write_GPS_coord(FileData *fd, const gchar *key, gdouble value)
@@ -863,7 +877,8 @@ gboolean metadata_write_GPS_coord(FileData *fd, const gchar *key, gdouble value)
 	char *coordinate;
 	const char *ref;
 	gboolean ok = TRUE;
-	char *old_locale, *saved_locale;
+	char *old_locale;
+	char *saved_locale;
 
 	param = value;
 	if (param < 0)
@@ -916,16 +931,14 @@ gboolean metadata_append_list(FileData *fd, const gchar *key, const GList *value
 		{
 		return metadata_write_list(fd, key, values);
 		}
-	else
-		{
-		gboolean ret;
-		list = g_list_concat(list, string_list_copy(values));
-		list = remove_duplicate_strings_from_list(list);
 
-		ret = metadata_write_list(fd, key, list);
-		g_list_free_full(list, g_free);
-		return ret;
-		}
+	gboolean ret;
+	list = g_list_concat(list, string_list_copy(values));
+	list = remove_duplicate_strings_from_list(list);
+
+	ret = metadata_write_list(fd, key, list);
+	g_list_free_full(list, g_free);
+	return ret;
 }
 
 /**
@@ -997,8 +1010,8 @@ gchar *find_string_in_list(GList *list, const gchar *string)
 {
 	if (options->metadata.keywords_case_sensitive)
 		return find_string_in_list_utf8case(list, string);
-	else
-		return find_string_in_list_utf8nocase(list, string);
+
+	return find_string_in_list_utf8nocase(list, string);
 }
 
 #define KEYWORDS_SEPARATOR(c) ((c) == ',' || (c) == ';' || (c) == '\n' || (c) == '\r' || (c) == '\b')
@@ -1205,10 +1218,8 @@ gboolean keyword_same_parent(GtkTreeModel *keyword_tree, GtkTreeIter *a, GtkTree
 		{
 		return keyword_compare(keyword_tree, &parent_a, &parent_b) == 0;
 		}
-	else
-		{
-		return (!valid_pa && !valid_pb); /* both are toplevel */
-		}
+
+	return (!valid_pa && !valid_pb); /* both are toplevel */
 }
 
 gboolean keyword_exists(GtkTreeModel *keyword_tree, GtkTreeIter *parent_ptr, GtkTreeIter *sibling, const gchar *name, gboolean exclude_sibling, GtkTreeIter *result)
@@ -1269,7 +1280,9 @@ gboolean keyword_exists(GtkTreeModel *keyword_tree, GtkTreeIter *parent_ptr, Gtk
 void keyword_copy(GtkTreeStore *keyword_tree, GtkTreeIter *to, GtkTreeIter *from)
 {
 
-	gchar *mark, *name, *casefold;
+	gchar *mark;
+	gchar *name;
+	gchar *casefold;
 	gboolean is_keyword;
 
 	/* do not copy KEYWORD_COLUMN_HIDE_IN, it fully shows the new subtree */
@@ -1728,7 +1741,8 @@ static GtkTreeIter keyword_tree_default_append(GtkTreeStore *keyword_tree, GtkTr
 
 void keyword_tree_new_default()
 {
-	GtkTreeIter i1, i2;
+	GtkTreeIter i1;
+	GtkTreeIter i2;
 
 	if (!keyword_tree) keyword_tree_new();
 
