@@ -18,16 +18,25 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <clocale>
-#include <memory>
-
-#include "main.h"
 #include "misc.h"
 
-#include "filedata.h"
-#include "ui-fileops.h"
+#include <sys/stat.h>
+#include <unistd.h>
+
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+#include <memory>
 
 #include <langinfo.h>
+#include <pwd.h>
+
+#include <config.h>
+
+#include "debug.h"
+#include "main.h"
+#include "options.h"
+#include "ui-fileops.h"
 
 gdouble get_zoom_increment()
 {
@@ -49,8 +58,10 @@ gchar *utf8_validate_or_convert(const gchar *text)
 
 gint utf8_compare(const gchar *s1, const gchar *s2, gboolean case_sensitive)
 {
-	gchar *s1_key, *s2_key;
-	gchar *s1_t, *s2_t;
+	gchar *s1_key;
+	gchar *s2_key;
+	gchar *s1_t;
+	gchar *s2_t;
 	gint ret;
 
 	g_assert(g_utf8_validate(s1, -1, nullptr));
@@ -126,8 +137,8 @@ gchar *expand_tilde(const gchar *filename)
 
 	if (slash)
 		return g_build_filename(home, G_DIR_SEPARATOR_S, slash + 1, NULL);
-	else
-		return g_build_filename(home, G_DIR_SEPARATOR_S, NULL);
+
+	return g_build_filename(home, G_DIR_SEPARATOR_S, NULL);
 #endif
 }
 
@@ -135,7 +146,9 @@ gchar *expand_tilde(const gchar *filename)
  */
 
 #define GEOCODE_NAME "geocode-parameters.awk"
-#define BUFSIZE 128
+enum {
+	BUFSIZE = 128
+};
 
 gchar *decode_geo_script(const gchar *path_dir, const gchar *input_text)
 {
@@ -257,7 +270,7 @@ int runcmd(const gchar *cmd)
  */
 gint date_get_first_day_of_week()
 {
-#ifdef HAVE__NL_TIME_FIRST_WEEKDAY
+#if HAVE__NL_TIME_FIRST_WEEKDAY
 	return nl_langinfo(_NL_TIME_FIRST_WEEKDAY)[0];
 #else
 	gchar *dot;
@@ -378,7 +391,7 @@ gint get_cpu_cores()
     return sysconf(_SC_NPROCESSORS_ONLN);
 }
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 void convert_gdkcolor_to_gdkrgba(gpointer data, GdkRGBA *gdk_rgba)
 {
 /* @FIXME GTK4 stub */
@@ -421,192 +434,4 @@ void gq_gtk_grid_attach_default(GtkGrid *grid, GtkWidget *child, guint left_atta
 	gtk_grid_attach(grid, child, left_attach, top_attach, right_attach - left_attach, bottom_attach - top_attach);
 }
 
-/* Copied from the libarchive .repo. examples */
-
-#ifndef HAVE_ARCHIVE
-gchar *open_archive(FileData *)
-{
-	log_printf("%s", _("Warning: libarchive not installed"));
-	return NULL;
-}
-
-#else
-
-#include <archive.h>
-#include <archive_entry.h>
-
-static void errmsg(const char *);
-static gboolean extract(const char *filename, int do_extract, int flags);
-static int copy_data(struct archive *, struct archive *);
-static void msg(const char *);
-static int verbose = 0;
-
-gchar *open_archive(FileData *fd)
-{
-	int flags;
-	gchar *current_dir;
-	gchar *destination_dir;
-	gboolean success;
-	gint error;
-
-	destination_dir = g_build_filename(g_get_tmp_dir(), GQ_ARCHIVE_DIR, instance_identifier, fd->path, NULL);
-
-	if (!recursive_mkdir_if_not_exists(destination_dir, 0755))
-		{
-		log_printf("%s%s%s", _("Open Archive - Cannot create directory: "), destination_dir, "\n");
-		g_free(destination_dir);
-		return nullptr;
-		}
-
-	current_dir = g_get_current_dir();
-	error = chdir(destination_dir);
-	if (error)
-		{
-		log_printf("%s%s%s%s%s", _("Open Archive - Cannot change directory to: "), destination_dir, _("\n  Error code: "), strerror(errno), "\n");
-		g_free(destination_dir);
-		g_free(current_dir);
-		return nullptr;
-		}
-
-	flags = ARCHIVE_EXTRACT_TIME;
-	success = extract(fd->path, 1, flags);
-
-	error = chdir(current_dir);
-	if (error)
-		{
-		log_printf("%s%s%s%s%s", _("Open Archive - Cannot change directory to: "), current_dir, _("\n  Error code: "), strerror(errno), "\n");
-		g_free(destination_dir);
-		g_free(current_dir);
-		return nullptr;
-		}
-	g_free(current_dir);
-
-	if (!success)
-		{
-		g_free(destination_dir);
-		destination_dir = nullptr;
-		}
-
-	return destination_dir;
-}
-
-static gboolean extract(const char *filename, int do_extract, int flags)
-{
-	struct archive *a;
-	struct archive *ext;
-	struct archive_entry *entry;
-	int r;
-
-	a = archive_read_new();
-	ext = archive_write_disk_new();
-	archive_write_disk_set_options(ext, flags);
-	archive_write_disk_set_standard_lookup(ext);
-	archive_read_support_filter_all(a);
-	archive_read_support_format_all(a);
-
-	if (filename != nullptr && strcmp(filename, "-") == 0)
-		{
-		filename = nullptr;
-		}
-	if ((r = archive_read_open_filename(a, filename, 10240)))
-		{
-		errmsg(archive_error_string(a));
-		errmsg("\n");
-		return(FALSE);
-		}
-	for (;;)
-		{
-		int needcr = 0;
-
-		r = archive_read_next_header(a, &entry);
-		if (r == ARCHIVE_EOF)
-			{
-			break;
-			}
-		if (r != ARCHIVE_OK)
-			{
-			errmsg(archive_error_string(a));
-			errmsg("\n");
-			return(FALSE);
-			}
-		if (verbose && do_extract)
-			{
-			msg("x ");
-			}
-		if (verbose || !do_extract)
-			{
-			msg(archive_entry_pathname(entry));
-			msg(" ");
-			needcr = 1;
-			}
-		if (do_extract)
-			{
-			r = archive_write_header(ext, entry);
-			if (r != ARCHIVE_OK)
-				{
-				errmsg(archive_error_string(a));
-				needcr = 1;
-				}
-			else
-				{
-				r = copy_data(a, ext);
-				if (r != ARCHIVE_OK)
-					{
-					needcr = 1;
-					}
-				}
-			}
-		if (needcr)
-			{
-			msg("\n");
-			}
-		}
-	archive_read_close(a);
-	archive_read_free(a);
-
-	archive_write_close(ext);
-	archive_write_free(ext);
-	return(TRUE);
-}
-
-static int copy_data(struct archive *ar, struct archive *aw)
-{
-	int r;
-	const void *buff;
-	size_t size;
-	int64_t offset;
-
-	for (;;)
-		{
-		r = archive_read_data_block(ar, &buff, &size, &offset);
-		if (r == ARCHIVE_EOF)
-			return (ARCHIVE_OK);
-		if (r != ARCHIVE_OK)
-			{
-			errmsg(archive_error_string(ar));
-			return (r);
-			}
-		r = archive_write_data_block(aw, buff, size, offset);
-		if (r != ARCHIVE_OK)
-			{
-			errmsg(archive_error_string(ar));
-			return (r);
-			}
-		}
-}
-
-static void msg(const char *m)
-{
-	log_printf("Open Archive - libarchive error: %s \n", m);
-}
-
-static void errmsg(const char *m)
-{
-	if (m == nullptr)
-		{
-		m = "Error: No error description provided.\n";
-		}
-	log_printf("Open Archive - libarchive error: %s \n", m);
-}
-#endif
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
