@@ -22,38 +22,57 @@
 #include "pan-calendar.h"
 
 #include <cmath>
+#include <cstring>
+#include <ctime>
 
+#include "debug.h"
+#include "filedata.h"
 #include "misc.h"
+#include "pan-item.h"
+#include "pan-types.h"
 #include "pan-util.h"
-#include "pan-view.h"
 #include "pan-view-filter.h"
+#include "pan-view.h"
 #include "pixbuf-util.h"
+#include "typedefs.h"
 
 #define PAN_CAL_POPUP_COLOR 220, 220, 220
-#define PAN_CAL_POPUP_ALPHA 255
-#define PAN_CAL_POPUP_BORDER 1
+enum {
+	PAN_CAL_POPUP_ALPHA = 255,
+	PAN_CAL_POPUP_BORDER = 1
+};
 #define PAN_CAL_POPUP_BORDER_COLOR 0, 0, 0
 #define PAN_CAL_POPUP_TEXT_COLOR 0, 0, 0
 
-#define PAN_CAL_DAY_WIDTH 100
-#define PAN_CAL_DAY_HEIGHT 80
+enum {
+	PAN_CAL_DAY_WIDTH = 100,
+	PAN_CAL_DAY_HEIGHT = 80
+};
 
 #define PAN_CAL_DAY_COLOR 255, 255, 255
-#define PAN_CAL_DAY_ALPHA 220
-#define PAN_CAL_DAY_BORDER 2
+enum {
+	PAN_CAL_DAY_ALPHA = 220,
+	PAN_CAL_DAY_BORDER = 2
+};
 #define PAN_CAL_DAY_BORDER_COLOR 0, 0, 0
 #define PAN_CAL_DAY_TEXT_COLOR 0, 0, 0
 
 #define PAN_CAL_MONTH_COLOR 255, 255, 255
-#define PAN_CAL_MONTH_ALPHA 200
-#define PAN_CAL_MONTH_BORDER 4
+enum {
+	PAN_CAL_MONTH_ALPHA = 200,
+	PAN_CAL_MONTH_BORDER = 4
+};
 #define PAN_CAL_MONTH_BORDER_COLOR 0, 0, 0
 #define PAN_CAL_MONTH_TEXT_COLOR 0, 0, 0
 
-#define PAN_CAL_DOT_SIZE 3
-#define PAN_CAL_DOT_GAP 2
+enum {
+	PAN_CAL_DOT_SIZE = 3,
+	PAN_CAL_DOT_GAP = 2
+};
 #define PAN_CAL_DOT_COLOR 128, 128, 128
-#define PAN_CAL_DOT_ALPHA 128
+enum {
+	PAN_CAL_DOT_ALPHA = 128
+};
 
 #define PAN_CAL_DAY_OF_WEEK_COLOR 128, 128, 128
 
@@ -69,8 +88,16 @@ void pan_calendar_update(PanWindow *pw, PanItem *pi_day)
 	PanItem *pi;
 	GList *list;
 	GList *work;
-	gint x1, y1, x2, y2, x3, y3;
-	gint x, y, w, h;
+	gint x1;
+	gint y1;
+	gint x2;
+	gint y2;
+	gint x3;
+	gint y3;
+	gint x;
+	gint y;
+	gint w;
+	gint h;
 	gint grid;
 	gint column;
 
@@ -191,7 +218,8 @@ void pan_calendar_compute(PanWindow *pw, FileData *dir_fd, gint *width, gint *he
 {
 	GList *list;
 	GList *work;
-	gint x, y;
+	gint x;
+	gint y;
 	time_t tc;
 	gint count;
 	gint day_max;
@@ -273,7 +301,6 @@ void pan_calendar_compute(PanWindow *pw, FileData *dir_fd, gint *width, gint *he
 		gint day;
 		gint days;
 		gint col;
-		gint row;
 		time_t dt;
 		gchar *buf;
 
@@ -298,7 +325,6 @@ void pan_calendar_compute(PanWindow *pw, FileData *dir_fd, gint *width, gint *he
 		col = pan_date_value(dt, PAN_DATE_LENGTH_WEEK);
 		col = col - (date_get_first_day_of_week() - 1);
 		if (col < 0) col = col + 7;
-		row = 1;
 
 		x = PAN_BOX_BORDER;
 
@@ -323,7 +349,8 @@ void pan_calendar_compute(PanWindow *pw, FileData *dir_fd, gint *width, gint *he
 			{
 			FileData *fd;
 			PanItem *pi_day;
-			gint dx, dy;
+			gint dx;
+			gint dy;
 			gint n = 0;
 			gchar fake_path[20];
 
@@ -413,7 +440,6 @@ void pan_calendar_compute(PanWindow *pw, FileData *dir_fd, gint *width, gint *he
 			if (col > 6)
 				{
 				col = 0;
-				row++;
 				x = PAN_BOX_BORDER;
 				y += PAN_CAL_DAY_HEIGHT;
 				}
