@@ -22,8 +22,10 @@
 #ifndef PAN_VIEW_PAN_FOLDER_H
 #define PAN_VIEW_PAN_FOLDER_H
 
-#include "main.h"
-#include "pan-types.h"
+#include <glib.h>
+
+struct FileData;
+struct PanWindow;
 
 void pan_flower_compute(PanWindow *pw, FileData *dir_fd,
 			gint *width, gint *height,
