@@ -21,16 +21,22 @@
 
 #include "pan-timeline.h"
 
+#include <ctime>
+
+#include "filedata.h"
 #include "pan-item.h"
+#include "pan-types.h"
 #include "pan-util.h"
-#include "pan-view.h"
 #include "pan-view-filter.h"
+#include "pan-view.h"
+#include "typedefs.h"
 
 void pan_timeline_compute(PanWindow *pw, FileData *dir_fd, gint *width, gint *height)
 {
 	GList *list;
 	GList *work;
-	gint x, y;
+	gint x;
+	gint y;
 	time_t group_start_date;
 	gint total;
 	gint count;
