@@ -21,6 +21,14 @@
 
 #include "pan-util.h"
 
+#include <features.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
+#include <cstring>
+
+#include "filedata.h"
+#include "main-defines.h"
 #include "ui-fileops.h"
 
 
