@@ -21,44 +21,70 @@
 
 #include "pan-view.h"
 
+#include <cmath>
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <gtk/gtk.h>
+
 #include "bar-exif.h"
+#include "cache-loader.h"
+#include "cache.h"
+#include "compat.h"
+#include "debug.h"
 #include "dnd.h"
 #include "editors.h"
 #include "exif.h"
+#include "filedata.h"
 #include "fullscreen.h"
+#include "image-load.h"
 #include "image.h"
 #include "img-view.h"
+#include "intl.h"
 #include "layout-util.h"
+#include "layout.h"
+#include "main-defines.h"
+#include "main.h"
 #include "menu.h"
 #include "metadata.h"
-#include "misc.h"
+#include "options.h"
 #include "pan-calendar.h"
 #include "pan-folder.h"
 #include "pan-grid.h"
+#include "pan-item.h"
 #include "pan-timeline.h"
+#include "pan-types.h"
 #include "pan-util.h"
 #include "pan-view-filter.h"
 #include "pan-view-search.h"
+#include "pixbuf-renderer.h"
 #include "pixbuf-util.h"
 #include "thumb.h"
 #include "ui-fileops.h"
 #include "ui-menu.h"
 #include "ui-misc.h"
 #include "ui-tabcomp.h"
+#include "ui-utildlg.h"
 #include "uri-utils.h"
 #include "utilops.h"
 #include "window.h"
 
-#include <cmath>
 
+enum {
+	PAN_WINDOW_DEFAULT_WIDTH = 720,
+	PAN_WINDOW_DEFAULT_HEIGHT = 500
+};
 
-#define PAN_WINDOW_DEFAULT_WIDTH 720
-#define PAN_WINDOW_DEFAULT_HEIGHT 500
-
-#define PAN_TILE_SIZE 512
+enum {
+	PAN_TILE_SIZE = 512
+};
 
 #define ZOOM_INCREMENT 1.0
-#define ZOOM_LABEL_WIDTH 64
+enum {
+	ZOOM_LABEL_WIDTH = 64
+};
 
 
 #define PAN_PREF_GROUP		"pan_view_options"
@@ -334,7 +360,10 @@ static gboolean pan_window_request_tile_cb(PixbufRenderer *pr, gint x, gint y,
 
 	for (i = (x / PAN_GRID_SIZE) * PAN_GRID_SIZE; i < x + width; i += PAN_GRID_SIZE)
 		{
-		gint rx, ry, rw, rh;
+		gint rx;
+		gint ry;
+		gint rw;
+		gint rh;
 
 		if (util_clip_region(x, y, width, height,
 				     i, y, 1, height,
@@ -347,7 +376,10 @@ static gboolean pan_window_request_tile_cb(PixbufRenderer *pr, gint x, gint y,
 		}
 	for (i = (y / PAN_GRID_SIZE) * PAN_GRID_SIZE; i < y + height; i += PAN_GRID_SIZE)
 		{
-		gint rx, ry, rw, rh;
+		gint rx;
+		gint ry;
+		gint rw;
+		gint rh;
 
 		if (util_clip_region(x, y, width, height,
 				     x, i, width, 1,
@@ -718,10 +750,13 @@ static void pan_grid_clear(PanWindow *pw)
 static void pan_grid_build(PanWindow *pw, gint width, gint height, gint grid_size)
 {
 	GList *work;
-	gint col, row;
-	gint cw, ch;
+	gint col;
+	gint row;
+	gint cw;
+	gint ch;
 	gint l;
-	gint i, j;
+	gint i;
+	gint j;
 
 	pan_grid_clear(pw);
 
@@ -775,7 +810,10 @@ static void pan_grid_build(PanWindow *pw, gint width, gint height, gint grid_siz
 		while (grid)
 			{
 			PanGrid *pg;
-			gint rx, ry, rw, rh;
+			gint rx;
+			gint ry;
+			gint rw;
+			gint rh;
 
 			pg = static_cast<PanGrid *>(grid->data);
 			grid = grid->next;
@@ -929,7 +967,10 @@ static GList *pan_layout_intersect_l(GList *list, GList *item_list,
 	while (work)
 		{
 		PanItem *pi;
-		gint rx, ry, rw, rh;
+		gint rx;
+		gint ry;
+		gint rw;
+		gint rh;
 
 		pi = static_cast<PanItem *>(work->data);
 		work = work->next;
@@ -1387,8 +1428,16 @@ void pan_info_update(PanWindow *pw, PanItem *pi)
 	PanItem *pbox;
 	PanItem *p;
 	gchar *buf;
-	gint x1, y1, x2, y2, x3, y3;
-	gint x, y, w, h;
+	gint x1;
+	gint y1;
+	gint x2;
+	gint y2;
+	gint x3;
+	gint y3;
+	gint x;
+	gint y;
+	gint w;
+	gint h;
 
 	if (pw->click_pi == pi) return;
 	if (pi && !pi->fd) pi = nullptr;
@@ -1458,7 +1507,8 @@ void pan_info_update(PanWindow *pw, PanItem *pi)
 
 	if (pw->info_image_size > PAN_IMAGE_SIZE_THUMB_NONE)
 		{
-		gint iw, ih;
+		gint iw;
+		gint ih;
 		if (image_load_dimensions(pi->fd, &iw, &ih))
 			{
 			gint scale = 25;
@@ -1516,7 +1566,8 @@ static void button_cb(PixbufRenderer *pr, GdkEventButton *event, gpointer data)
 	auto pw = static_cast<PanWindow *>(data);
 	PanItem *pi = nullptr;
 	GtkWidget *menu;
-	gint rx, ry;
+	gint rx;
+	gint ry;
 
 	rx = ry = 0;
 	if (pr->scale)
@@ -1560,7 +1611,8 @@ static void button_cb(PixbufRenderer *pr, GdkEventButton *event, gpointer data)
 
 static void scroll_cb(PixbufRenderer *pr, GdkEventScroll *event, gpointer)
 {
-	gint w, h;
+	gint w;
+	gint h;
 
 	w = pr->vis_width;
 	h = pr->vis_height;
@@ -1659,7 +1711,8 @@ static void pan_window_image_scroll_notify_cb(PixbufRenderer *pr, gpointer data)
 	auto pw = static_cast<PanWindow *>(data);
 	GtkAdjustment *adj;
 	GdkRectangle rect;
-	gint width, height;
+	gint width;
+	gint height;
 
 	if (pr->scale == 0.0) return;
 
@@ -1798,13 +1851,14 @@ static gboolean pan_window_delete_cb(GtkWidget *, GdkEventAny *, gpointer data)
 static void pan_window_new_real(FileData *dir_fd)
 {
 	PanWindow *pw;
-	GtkWidget *vbox;
+	GdkGeometry geometry;
 	GtkWidget *box;
 	GtkWidget *combo;
-	GtkWidget *hbox;
 	GtkWidget *frame;
-	GtkWidget *table;
-	GdkGeometry geometry;
+	GtkWidget *hbox;
+	GtkWidget *hbox_imd_widget;
+	GtkWidget *vbox;
+	GtkWidget *vbox_imd_widget;
 
 	pw = g_new0(PanWindow, 1);
 
@@ -1850,8 +1904,7 @@ static void pan_window_new_real(FileData *dir_fd)
 
 	pref_spacer(box, 0);
 	pref_label_new(box, _("Location:"));
-	combo = tab_completion_new_with_history(&pw->path_entry, dir_fd->path, "pan_view_path", -1,
-						pan_window_entry_activate_cb, pw);
+	combo = tab_completion_new_with_history(&pw->path_entry, dir_fd->path, "pan_view_path", -1, pan_window_entry_activate_cb, pw);
 	gq_gtk_box_pack_start(GTK_BOX(box), combo, TRUE, TRUE, 0);
 	gtk_widget_show(combo);
 
@@ -1863,8 +1916,7 @@ static void pan_window_new_real(FileData *dir_fd)
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Grid"));
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), pw->layout);
-	g_signal_connect(G_OBJECT(combo), "changed",
-			 G_CALLBACK(pan_window_layout_change_cb), pw);
+	g_signal_connect(G_OBJECT(combo), "changed", G_CALLBACK(pan_window_layout_change_cb), pw);
 	gq_gtk_box_pack_start(GTK_BOX(box), combo, FALSE, FALSE, 0);
 	gtk_widget_show(combo);
 
@@ -1881,50 +1933,52 @@ static void pan_window_new_real(FileData *dir_fd)
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("1:1 (100%)"));
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), pw->size);
-	g_signal_connect(G_OBJECT(combo), "changed",
-			 G_CALLBACK(pan_window_layout_size_cb), pw);
+	g_signal_connect(G_OBJECT(combo), "changed", G_CALLBACK(pan_window_layout_size_cb), pw);
 	gq_gtk_box_pack_start(GTK_BOX(box), combo, FALSE, FALSE, 0);
 	gtk_widget_show(combo);
 
-	table = pref_table_new(vbox, 2, 2, FALSE, TRUE);
-	gtk_grid_set_row_spacing(GTK_GRID(table), 2);
-	gtk_grid_set_column_spacing(GTK_GRID(table), 2);
-
 	pw->imd = image_new(TRUE);
 	pw->imd_normal = pw->imd;
 
-	g_signal_connect(G_OBJECT(pw->imd->pr), "zoom",
-			 G_CALLBACK(pan_window_image_zoom_cb), pw);
-	g_signal_connect(G_OBJECT(pw->imd->pr), "scroll_notify",
-			 G_CALLBACK(pan_window_image_scroll_notify_cb), pw);
+	g_signal_connect(G_OBJECT(pw->imd->pr), "zoom", G_CALLBACK(pan_window_image_zoom_cb), pw);
+	g_signal_connect(G_OBJECT(pw->imd->pr), "scroll_notify", G_CALLBACK(pan_window_image_scroll_notify_cb), pw);
 
-	gq_gtk_grid_attach(GTK_GRID(table), pw->imd->widget, 0, 1, 0, 1, static_cast<GtkAttachOptions>(GTK_FILL | GTK_EXPAND), static_cast<GtkAttachOptions>(GTK_FILL | GTK_EXPAND), 0, 0);
+	vbox_imd_widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+	hbox_imd_widget = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+
+	gtk_box_pack_start(GTK_BOX(vbox_imd_widget), pw->imd->widget, true, true, 0);
+
+	pw->scrollbar_h = gtk_scrollbar_new(GTK_ORIENTATION_HORIZONTAL, nullptr);
+	g_signal_connect(G_OBJECT(pw->scrollbar_h), "value_changed",  G_CALLBACK(pan_window_scrollbar_h_value_cb), pw);
+	gtk_box_pack_start(GTK_BOX(vbox_imd_widget), pw->scrollbar_h, false, false, 0);
+
+	gtk_box_pack_start(GTK_BOX(hbox_imd_widget), vbox_imd_widget, true, true, 0);
+
+	pw->scrollbar_v = gtk_scrollbar_new(GTK_ORIENTATION_VERTICAL, nullptr);
+	g_signal_connect(G_OBJECT(pw->scrollbar_v), "value_changed", G_CALLBACK(pan_window_scrollbar_v_value_cb), pw);
+	gtk_box_pack_start(GTK_BOX(hbox_imd_widget), pw->scrollbar_v, false, false, 0);
+
+	gtk_box_pack_start(GTK_BOX(vbox), hbox_imd_widget, true, true, 0);
+
+	gtk_widget_show(GTK_WIDGET(hbox_imd_widget));
 	gtk_widget_show(GTK_WIDGET(pw->imd->widget));
+	gtk_widget_show(GTK_WIDGET(vbox));
+	gtk_widget_show(GTK_WIDGET(vbox_imd_widget));
+	gtk_widget_show(pw->scrollbar_h);
+	gtk_widget_show(pw->scrollbar_v);
 
 	pan_window_dnd_init(pw);
 
 	pan_image_set_buttons(pw, pw->imd);
 
-	pw->scrollbar_h = gtk_scrollbar_new(GTK_ORIENTATION_HORIZONTAL, nullptr);
-	g_signal_connect(G_OBJECT(pw->scrollbar_h), "value_changed",
-			 G_CALLBACK(pan_window_scrollbar_h_value_cb), pw);
-	gq_gtk_grid_attach(GTK_GRID(table), pw->scrollbar_h, 0, 1, 1, 2,  static_cast<GtkAttachOptions>(GTK_FILL | GTK_EXPAND), static_cast<GtkAttachOptions>(0), 0, 0);
-	gtk_widget_show(pw->scrollbar_h);
-
-	pw->scrollbar_v = gtk_scrollbar_new(GTK_ORIENTATION_VERTICAL, nullptr);
-	g_signal_connect(G_OBJECT(pw->scrollbar_v), "value_changed",
-			 G_CALLBACK(pan_window_scrollbar_v_value_cb), pw);
-	gq_gtk_grid_attach(GTK_GRID(table), pw->scrollbar_v, 1, 2, 0, 1,  static_cast<GtkAttachOptions>(0), static_cast<GtkAttachOptions>(GTK_FILL | GTK_EXPAND), 0, 0);
-	gtk_widget_show(pw->scrollbar_v);
-
 	/* find bar */
 
 	pw->search_ui = pan_search_ui_new(pw);
 	gq_gtk_box_pack_start(GTK_BOX(vbox), pw->search_ui->search_box, FALSE, FALSE, 2);
 
-    /* filter bar */
-    pw->filter_ui = pan_filter_ui_new(pw);
-    gq_gtk_box_pack_start(GTK_BOX(vbox), pw->filter_ui->filter_box, FALSE, FALSE, 2);
+	/* filter bar */
+	pw->filter_ui = pan_filter_ui_new(pw);
+	gq_gtk_box_pack_start(GTK_BOX(vbox), pw->filter_ui->filter_box, FALSE, FALSE, 2);
 
 	/* status bar */
 
@@ -1963,10 +2017,8 @@ static void pan_window_new_real(FileData *dir_fd)
 	gq_gtk_box_pack_end(GTK_BOX(box), pw->filter_ui->filter_button, FALSE, FALSE, 0);
 	gtk_widget_show(pw->filter_ui->filter_button);
 
-	g_signal_connect(G_OBJECT(pw->window), "delete_event",
-			 G_CALLBACK(pan_window_delete_cb), pw);
-	g_signal_connect(G_OBJECT(pw->window), "key_press_event",
-			 G_CALLBACK(pan_window_key_press_cb), pw);
+	g_signal_connect(G_OBJECT(pw->window), "delete_event", G_CALLBACK(pan_window_delete_cb), pw);
+	g_signal_connect(G_OBJECT(pw->window), "key_press_event", G_CALLBACK(pan_window_key_press_cb), pw);
 
 	gtk_window_set_default_size(GTK_WINDOW(pw->window), PAN_WINDOW_DEFAULT_WIDTH, PAN_WINDOW_DEFAULT_HEIGHT);
 
@@ -2007,7 +2059,7 @@ static gboolean pan_warning(FileData *dir_fd)
 	GenericDialog *gd;
 	GtkWidget *box;
 	GtkWidget *group;
-	GtkWidget *button;
+	GtkWidget *checkbox;
 	GtkWidget *ct_button;
 	gboolean hide_dlg;
 
@@ -2039,9 +2091,9 @@ static gboolean pan_warning(FileData *dir_fd)
 
 	ct_button = pref_checkbox_new_int(group, _("Cache thumbnails"),
 					  options->thumbnails.enable_caching, &options->thumbnails.enable_caching);
-	button = pref_checkbox_new_int(group, _("Use shared thumbnail cache"),
+	checkbox = pref_checkbox_new_int(group, _("Use shared thumbnail cache"),
 				       options->thumbnails.spec_standard, &options->thumbnails.spec_standard);
-	pref_checkbox_link_sensitivity(ct_button, button);
+	pref_checkbox_link_sensitivity(ct_button, checkbox);
 
 	pref_line(box, 0);
 
@@ -2303,7 +2355,8 @@ static GtkWidget *pan_popup_menu(PanWindow *pw)
 	GtkWidget *menu;
 	GtkWidget *submenu;
 	GtkWidget *item;
-	gboolean active, video;
+	gboolean active;
+	gboolean video;
 	GList *editmenu_fd_list;
 	GtkAccelGroup *accel_group;
 
