@@ -22,6 +22,11 @@
 #ifndef PIXBUF_UTIL_H
 #define PIXBUF_UTIL_H
 
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+#include <pango/pango.h>
+
 struct FileData;
 
 gboolean pixbuf_to_file_as_png (GdkPixbuf *pixbuf, const gchar *filename);
