@@ -18,16 +18,29 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "print.h"
 
+#include <cstddef>
+
+#include <cairo.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <pango/pango.h>
+#include <pango/pangocairo.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "exif.h"
 #include "filedata.h"
 #include "image-load.h"
+#include "intl.h"
+#include "main-defines.h"
+#include "options.h"
 #include "osd.h"
 #include "pixbuf-util.h"
-#include "ui-misc.h"
 #include "ui-fileops.h"
+#include "ui-misc.h"
 
 #define PRINT_SETTINGS "print_settings" // filename save printer settings
 #define PAGE_SETUP "page_setup" // filename save page setup
@@ -343,7 +356,9 @@ static void image_text_template_view_changed_cb(GtkWidget *, gpointer data)
 					  gtk_text_buffer_get_text(pTextBuffer, &iStart, &iEnd, TRUE));
 }
 
-#define PRE_FORMATTED_COLUMNS 4
+enum {
+	PRE_FORMATTED_COLUMNS = 4
+};
 static void print_text_menu(GtkWidget *box, PrintWindow *pw)
 {
 	GtkWidget *group;
@@ -373,16 +388,16 @@ static void print_text_menu(GtkWidget *box, PrintWindow *pw)
 	gq_gtk_box_pack_start(GTK_BOX(subgroup), hbox, FALSE, FALSE, 0);
 
 	/* order is important */
-	button1 = pref_radiobutton_new(hbox, nullptr,  "Header 1",
+	button1 = pref_radiobutton_new(hbox, nullptr,  _("Header 1"),
 							options->printer.image_text_position == HEADER_1,
 							G_CALLBACK(image_text_position_h1_cb), pw);
-	button1 = pref_radiobutton_new(hbox, button1,  "Header 2",
+	button1 = pref_radiobutton_new(hbox, button1,  _("Header 2"),
 							options->printer.image_text_position == HEADER_2,
 							G_CALLBACK(image_text_position_h2_cb), pw);
-	button1 = pref_radiobutton_new(hbox, button1, "Footer 1",
+	button1 = pref_radiobutton_new(hbox, button1, _("Footer 1"),
 							options->printer.image_text_position == FOOTER_1,
 							G_CALLBACK(image_text_position_f1_cb), pw);
-	button1 = pref_radiobutton_new(hbox, button1, "Footer 2",
+	button1 = pref_radiobutton_new(hbox, button1, _("Footer 2"),
 							options->printer.image_text_position == FOOTER_2,
 							G_CALLBACK(image_text_position_f2_cb), pw);
 	gtk_widget_show(hbox);
@@ -436,16 +451,16 @@ static void print_text_menu(GtkWidget *box, PrintWindow *pw)
 	gq_gtk_box_pack_start(GTK_BOX(subgroup), hbox, FALSE, FALSE, 0);
 
 	/* order is important */
-	button2 = pref_radiobutton_new(hbox, nullptr, "Header 1",
+	button2 = pref_radiobutton_new(hbox, nullptr, _("Header 1"),
 							options->printer.page_text_position == HEADER_1,
 							G_CALLBACK(page_text_position_h1_cb), pw);
-	button2 = pref_radiobutton_new(hbox, button2,  "Header 2",
+	button2 = pref_radiobutton_new(hbox, button2,  _("Header 2"),
 							options->printer.page_text_position == HEADER_2,
 							G_CALLBACK(page_text_position_h2_cb), pw);
-	button2 = pref_radiobutton_new(hbox, button2, "Footer 1",
+	button2 = pref_radiobutton_new(hbox, button2, _("Footer 1"),
 							options->printer.page_text_position == FOOTER_1,
 							G_CALLBACK(page_text_position_f1_cb), pw);
-	button2 = pref_radiobutton_new(hbox, button2, "Footer 2",
+	button2 = pref_radiobutton_new(hbox, button2, _("Footer 2"),
 							options->printer.page_text_position == FOOTER_2,
 							G_CALLBACK(page_text_position_f2_cb), pw);
 	gtk_widget_show(hbox);
@@ -485,10 +500,8 @@ static gboolean paginate_cb(GtkPrintOperation *, GtkPrintContext *, gpointer dat
 		{
 		return TRUE;
 		}
-	else
-		{
-		return FALSE;
-		}
+
+	return FALSE;
 }
 
 gchar *form_image_text(const gchar *template_string, FileData *fd, PrintWindow *pw, gint page_nr, gint total)
@@ -531,7 +544,8 @@ gchar *form_image_text(const gchar *template_string, FileData *fd, PrintWindow *
 
 	if (fd->pixbuf)
 		{
-		gint w, h;
+		gint w;
+		gint h;
 		w = gdk_pixbuf_get_width(fd->pixbuf);
 		h = gdk_pixbuf_get_height(fd->pixbuf);
 
@@ -559,8 +573,10 @@ static void draw_page(GtkPrintOperation *, GtkPrintContext *context, gint page_n
 	auto pw = static_cast<PrintWindow *>(data);
 	FileData *fd;
 	cairo_t *cr;
-	gdouble context_width, context_height;
-	gdouble pixbuf_image_width, pixbuf_image_height;
+	gdouble context_width;
+	gdouble context_height;
+	gdouble pixbuf_image_width;
+	gdouble pixbuf_image_height;
 	gdouble width_offset;
 	gdouble height_offset;
 	GdkPixbuf *pixbuf;
@@ -570,15 +586,22 @@ static void draw_page(GtkPrintOperation *, GtkPrintContext *context, gint page_n
 	PangoFontDescription *desc;
 	GString *image_text = g_string_new(nullptr);
 	GString *page_text = g_string_new(nullptr);
-	PangoRectangle ink_rect, logical_rect;
-	gdouble w, h, scale;
-	gdouble image_text_width, image_text_height, page_text_width, page_text_height;
+	PangoRectangle ink_rect;
+	PangoRectangle logical_rect;
+	gdouble w;
+	gdouble h;
+	gdouble scale;
+	gdouble image_text_width;
+	gdouble image_text_height;
+	gdouble page_text_width;
+	gdouble page_text_height;
 	gint image_y;
 	gint incr_y;
 	gdouble pango_height;
 	gdouble pango_image_height;
 	gdouble pango_page_height;
-	GtkTextIter start, end;
+	GtkTextIter start;
+	GtkTextIter end;
 	gchar *tmp;
 	gint total;
 
@@ -787,7 +810,8 @@ GObject *option_tab_cb(GtkPrintOperation *, gpointer user_data)
 static void print_pref_store(PrintWindow *pw)
 {
 	gchar *tmp;
-	GtkTextIter start, end;
+	GtkTextIter start;
+	GtkTextIter end;
 
 	gtk_text_buffer_get_bounds(GTK_TEXT_BUFFER(pw->page_text), &start, &end);
 	tmp = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(pw->page_text), &start, &end, FALSE);
@@ -890,7 +914,7 @@ void print_window_new(FileData *, GList *selection, GList *, GtkWidget *parent)
 	operation = gtk_print_operation_new();
 	settings = gtk_print_settings_new();
 
-	gtk_print_operation_set_custom_tab_label(operation, "Options");
+	gtk_print_operation_set_custom_tab_label(operation, _("Options"));
 	gtk_print_operation_set_use_full_page(operation, TRUE);
 	gtk_print_operation_set_unit(operation, GTK_UNIT_POINTS);
 	gtk_print_operation_set_embed_page_setup(operation, TRUE);
