@@ -19,37 +19,58 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "remote.h"
 
+#include <sys/socket.h>
+#include <sys/stat.h>
+#include <sys/un.h>
+#include <unistd.h>
+
+#include <cerrno>
+#include <csignal>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
+
+#include <config.h>
+
+#include <gtk/gtk.h>
+
 #include "cache-maint.h"
-#include "collect.h"
 #include "collect-io.h"
+#include "collect.h"
+#include "compat.h"
+#include "debug.h"
 #include "exif.h"
 #include "filedata.h"
 #include "filefilter.h"
+#include "glua.h"
 #include "image.h"
 #include "img-view.h"
+#include "intl.h"
 #include "layout-image.h"
 #include "layout-util.h"
+#include "layout.h"
+#include "main-defines.h"
+#include "main.h"
 #include "misc.h"
+#include "options.h"
 #include "pixbuf-renderer.h"
+#include "rcfile.h"
 #include "slideshow.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
 #include "utilops.h"
-#include "rcfile.h"
 #include "view-file.h"
 
-#include <csignal>
-#include <sys/socket.h>
-#include <sys/un.h>
+enum {
+	SERVER_MAX_CLIENTS = 8
+};
 
-#include "glua.h"
-
-#define SERVER_MAX_CLIENTS 8
-
-#define REMOTE_SERVER_BACKLOG 4
+enum {
+	REMOTE_SERVER_BACKLOG = 4
+};
 
 
 #ifndef UNIX_PATH_MAX
@@ -345,7 +366,8 @@ static void sighandler_sigpipe(gint)
 
 static gboolean remote_client_send(RemoteConnection *rc, const gchar *text)
 {
-	struct sigaction new_action, old_action;
+	struct sigaction new_action;
+	struct sigaction old_action;
 	gboolean ret = FALSE;
 	GError *error = nullptr;
 	GIOChannel *channel;
@@ -614,7 +636,10 @@ static void gr_slideshow_stop(const gchar *, GIOChannel *, gpointer)
 
 static void gr_slideshow_delay(const gchar *text, GIOChannel *, gpointer)
 {
-	gdouble t1, t2, t3, n;
+	gdouble t1;
+	gdouble t2;
+	gdouble t3;
+	gdouble n;
 	gint res;
 
 	res = sscanf(text, "%lf:%lf:%lf", &t1, &t2, &t3);
@@ -741,9 +766,13 @@ static void gr_file_load(const gchar *text, GIOChannel *channel, gpointer data)
 static void gr_pixel_info(const gchar *, GIOChannel *channel, gpointer)
 {
 	gchar *pixel_info;
-	gint x_pixel, y_pixel;
-	gint width, height;
-	gint r_mouse, g_mouse, b_mouse;
+	gint x_pixel;
+	gint y_pixel;
+	gint width;
+	gint height;
+	gint r_mouse;
+	gint g_mouse;
+	gint b_mouse;
 	PixbufRenderer *pr;
 
 	if (!layout_valid(&lw_id)) return;
@@ -786,7 +815,10 @@ static void gr_rectangle(const gchar *, GIOChannel *channel, gpointer)
 {
 	gchar *rectangle_info;
 	PixbufRenderer *pr;
-	gint x1, y1, x2, y2;
+	gint x1;
+	gint y1;
+	gint x2;
+	gint y2;
 
 	if (!options->draw_rectangle) return;
 	if (!layout_valid(&lw_id)) return;
@@ -1632,7 +1664,7 @@ static void gr_print0(const gchar *, GIOChannel *channel, gpointer)
 	g_io_channel_write_chars(channel, "<gq_end_of_command>", -1, nullptr, nullptr);
 }
 
-#ifdef HAVE_LUA
+#if HAVE_LUA
 static void gr_lua(const gchar *text, GIOChannel *channel, gpointer)
 {
 	gchar *result = nullptr;
@@ -1713,7 +1745,7 @@ static RemoteCommandEntry remote_commands[] = {
 	{ nullptr, "--last",               gr_image_last,          FALSE, FALSE, nullptr, N_("last image") },
 	{ nullptr, "--list-add:",          gr_list_add,            TRUE,  FALSE, N_("<FILE>"), N_("add FILE to command line collection list") },
 	{ nullptr, "--list-clear",         gr_list_clear,          FALSE, FALSE, nullptr, N_("clear command line collection list") },
-#ifdef HAVE_LUA
+#if HAVE_LUA
 	{ nullptr, "--lua:",               gr_lua,                 TRUE, FALSE, N_("<FILE>,<lua script>"), N_("run lua script on FILE") },
 #endif
 	{ nullptr, "--new-window",         gr_new_window,          FALSE, FALSE, nullptr, N_("new window") },
@@ -1755,7 +1787,8 @@ static RemoteCommandEntry *remote_command_find(const gchar *text, const gchar **
 				if (offset) *offset = text + strlen(remote_commands[i].opt_s);
 				return &remote_commands[i];
 				}
-			else if (remote_commands[i].opt_l &&
+
+			if (remote_commands[i].opt_l &&
 				 strncmp(remote_commands[i].opt_l, text, strlen(remote_commands[i].opt_l)) == 0)
 				{
 				if (offset) *offset = text + strlen(remote_commands[i].opt_l);
