@@ -19,19 +19,32 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "thumb-standard.h"
 
+#include <sys/stat.h>
+
+#include <cstdlib>
+#include <cstring>
+#include <ctime>
+
+#include <glib-object.h>
+
+#include <config.h>
+
 #include "cache.h"
+#include "color-man.h"
+#include "debug.h"
+#include "exif.h"
+#include "filedata.h"
 #include "image-load.h"
 #include "md5-util.h"
-#include "pixbuf-util.h"
-#include "ui-fileops.h"
-#include "filedata.h"
-#include "exif.h"
 #include "metadata.h"
-#include "color-man.h"
+#include "options.h"
+#include "pixbuf-util.h"
+#include "typedefs.h"
+#include "ui-fileops.h"
 
+struct ExifData;
 
 /**
  * @file
@@ -53,8 +66,10 @@
  */
 
 
-#define THUMB_SIZE_NORMAL 128
-#define THUMB_SIZE_LARGE  256
+enum {
+	THUMB_SIZE_NORMAL = 128,
+	THUMB_SIZE_LARGE =  256
+};
 
 #define THUMB_MARKER_URI    "tEXt::Thumb::URI"
 #define THUMB_MARKER_MTIME  "tEXt::Thumb::MTime"
@@ -63,11 +78,6 @@
 #define THUMB_MARKER_HEIGHT "tEXt::Thumb::Image::Height"
 #define THUMB_MARKER_APP    "tEXt::Software"
 
-#define THUMB_PERMS_FOLDER 0700
-#define THUMB_PERMS_THUMB  0600
-
-
-
 /*
  *-----------------------------------------------------------------------------
  * thumbnail loader
@@ -170,7 +180,8 @@ static gchar *thumb_std_cache_path(const gchar *path, const gchar *uri, gboolean
 static gchar *thumb_loader_std_cache_path(ThumbLoaderStd *tl, gboolean local, GdkPixbuf *pixbuf, gboolean fail)
 {
 	const gchar *folder;
-	gint w, h;
+	gint w;
+	gint h;
 
 	if (!tl->fd || !tl->thumb_uri) return nullptr;
 
@@ -254,7 +265,8 @@ static gboolean thumb_loader_std_validate(ThumbLoaderStd *tl, GdkPixbuf *pixbuf)
 	const gchar *uri;
 	const gchar *mtime_str;
 	time_t mtime;
-	gint w, h;
+	gint w;
+	gint h;
 
 	if (!pixbuf) return FALSE;
 
@@ -328,7 +340,7 @@ static void thumb_loader_std_save(ThumbLoaderStd *tl, GdkPixbuf *pixbuf)
 		}
 	else
 		{
-		recursive_mkdir_if_not_exists(base_path, THUMB_PERMS_FOLDER);
+		recursive_mkdir_if_not_exists(base_path, S_IRWXU);
 		}
 	g_free(base_path);
 
@@ -357,7 +369,7 @@ static void thumb_loader_std_save(ThumbLoaderStd *tl, GdkPixbuf *pixbuf)
 					  NULL);
 		if (success)
 			{
-			chmod(pathl, (tl->cache_local) ? tl->source_mode : THUMB_PERMS_THUMB);
+			chmod(pathl, (tl->cache_local) ? tl->source_mode : S_IRUSR & S_IWUSR);
 			success = rename_file(tmp_path, tl->thumb_path);
 			}
 
@@ -394,7 +406,8 @@ void thumb_loader_std_calibrate_pixbuf(FileData *fd, GdkPixbuf *pixbuf) {
 	const gchar *input_file = nullptr;
 	guchar *profile = nullptr;
 	guint profile_len;
-	gint sw, sh;
+	gint sw;
+	gint sh;
 
 	if (!options->thumbnails.use_color_management)
 		{
@@ -496,7 +509,8 @@ static GdkPixbuf *thumb_loader_std_finish(ThumbLoaderStd *tl, GdkPixbuf *pixbuf,
 	GdkPixbuf *pixbuf_thumb = nullptr;
 	GdkPixbuf *result;
 	GdkPixbuf *rotated = nullptr;
-	gint sw, sh;
+	gint sw;
+	gint sh;
 
 
 	if (!tl->cache_hit && options->image.exif_rotate_enable)
@@ -527,7 +541,8 @@ static GdkPixbuf *thumb_loader_std_finish(ThumbLoaderStd *tl, GdkPixbuf *pixbuf,
 		{
 		if (!tl->cache_hit)
 			{
-			gint cache_w, cache_h;
+			gint cache_w;
+			gint cache_h;
 
 			if (tl->requested_width > THUMB_SIZE_NORMAL || tl->requested_height > THUMB_SIZE_NORMAL)
 				{
@@ -540,7 +555,8 @@ static GdkPixbuf *thumb_loader_std_finish(ThumbLoaderStd *tl, GdkPixbuf *pixbuf,
 
 			if (sw > cache_w || sh > cache_h || shrunk)
 				{
-				gint thumb_w, thumb_h;
+				gint thumb_w;
+				gint thumb_h;
 				struct stat st;
 
 				if (pixbuf_scale_aspect(cache_w, cache_h, sw, sh,
@@ -589,7 +605,8 @@ static GdkPixbuf *thumb_loader_std_finish(ThumbLoaderStd *tl, GdkPixbuf *pixbuf,
 		}
 	else
 		{
-		gint thumb_w, thumb_h;
+		gint thumb_w;
+		gint thumb_h;
 
 		if (pixbuf_thumb)
 			{
