@@ -19,15 +19,25 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "ui-bookmark.h"
+
+#include <cstdlib>
 #include <cstring>
 #include <memory>
 
-#include "main.h"
-#include "ui-bookmark.h"
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+#include <pango/pango.h>
 
+#include "compat.h"
+#include "debug.h"
 #include "history-list.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "misc.h"
 #include "pixbuf-util.h"
+#include "typedefs.h"
 #include "ui-fileops.h"
 #include "ui-menu.h"
 #include "ui-misc.h"
@@ -96,13 +106,17 @@ static GtkTargetEntry bookmark_drop_types[] = {
 	{ const_cast<gchar *>("x-url/http"),    0, TARGET_X_URL },
 	{ const_cast<gchar *>("_NETSCAPE_URL"), 0, TARGET_X_URL }
 };
-#define bookmark_drop_types_n 3
+enum {
+	bookmark_drop_types_n = 3
+};
 
 static GtkTargetEntry bookmark_drag_types[] = {
 	{ const_cast<gchar *>("text/uri-list"), 0, TARGET_URI_LIST },
 	{ const_cast<gchar *>("text/plain"),    0, TARGET_TEXT_PLAIN }
 };
-#define bookmark_drag_types_n 2
+enum {
+	bookmark_drag_types_n = 2
+};
 
 
 static GList *bookmark_widget_list = nullptr;
@@ -480,7 +494,8 @@ static void bookmark_drag_begin(GtkWidget *button, GdkDragContext *context, gpoi
 {
 	GdkPixbuf *pixbuf;
 	GdkModifierType mask;
-	gint x, y;
+	gint x;
+	gint y;
 	GtkAllocation allocation;
 	GdkSeat *seat;
 	GdkDevice *device;
@@ -630,7 +645,8 @@ static void bookmark_populate(BookMarkData *bm)
 					}
 				else
 					{
-					gint w, h;
+					gint w;
+					gint h;
 
 					w = h = 16;
 					gtk_icon_size_lookup(GTK_ICON_SIZE_BUTTON, &w, &h);
@@ -642,7 +658,8 @@ static void bookmark_populate(BookMarkData *bm)
 				if (pixbuf)
 					{
 					GdkPixbuf *scaled;
-					gint w, h;
+					gint w;
+					gint h;
 
 					w = h = 16;
 					gtk_icon_size_lookup(GTK_ICON_SIZE_BUTTON, &w, &h);
@@ -804,7 +821,8 @@ GtkWidget *bookmark_list_new(const gchar *key,
 	scrolled = gq_gtk_scrolled_window_new(nullptr, nullptr);
 
 	PangoLayout *layout;
-	gint width, height;
+	gint width;
+	gint height;
 
 	layout = gtk_widget_create_pango_layout(GTK_WIDGET(scrolled), "reasonable width");
 	pango_layout_get_pixel_size(layout, &width, &height);
