@@ -19,10 +19,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
-#include "layout.h"
 #include "ui-menu.h"
 
+#include <cstddef>
+
+#include <pango/pango.h>
+
+#include "layout.h"
 
 /*
  *-----------------------------------------------------------------------------
@@ -429,8 +432,10 @@ GtkWidget *popup_menu_short_lived()
 gboolean popup_menu_position_clamp(GtkMenu *menu, gint *x, gint *y, gint height)
 {
 	gboolean adjusted = FALSE;
-	gint w, h;
-	gint xw, xh;
+	gint w;
+	gint h;
+	gint xw;
+	gint xh;
 	GtkRequisition requisition;
 
 	gtk_widget_get_requisition(GTK_WIDGET(menu), &requisition);
