@@ -19,19 +19,27 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "ui-misc.h"
+
+#include <langinfo.h>
+
 #include <cstdlib>
 #include <cstring>
 
-#include "main.h"
+#include <pango/pango.h>
 
+#include <config.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "history-list.h"
 #include "layout.h"
+#include "main-defines.h"
 #include "misc.h"
-#include "ui-misc.h"
+#include "options.h"
+#include "typedefs.h"
 #include "utilops.h"
 
-#include <langinfo.h>
-
 /*
  *-----------------------------------------------------------------------------
  * widget and layout utilities
@@ -337,7 +345,7 @@ void pref_checkbox_link_sensitivity(GtkWidget *button, GtkWidget *widget)
 #pragma GCC diagnostic ignored "-Wunused-function"
 static void pref_checkbox_link_sensitivity_swap_cb_unused(GtkWidget *button, gpointer data)
 {
-	GtkWidget *widget = static_cast<GtkWidget *>(data);
+	auto *widget = static_cast<GtkWidget *>(data);
 
 	gtk_widget_set_sensitive(widget, !gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)));
 }
@@ -356,7 +364,7 @@ static GtkWidget *real_pref_radiobutton_new(GtkWidget *parent_box, GtkWidget *si
 					    GCallback func, gpointer data)
 {
 	GtkWidget *button;
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 	GtkToggleButton *group;;
 #else
 	GSList *group;
@@ -364,7 +372,7 @@ static GtkWidget *real_pref_radiobutton_new(GtkWidget *parent_box, GtkWidget *si
 
 	if (sibling)
 		{
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 		group = sibling;
 #else
 		group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(sibling));
@@ -377,7 +385,7 @@ static GtkWidget *real_pref_radiobutton_new(GtkWidget *parent_box, GtkWidget *si
 
 	if (mnemonic_text)
 		{
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 		button = gtk_toggle_button_new_with_mnemonic(text);
 		gtk_toggle_button_set_group(button, group);
 #else
@@ -386,7 +394,7 @@ static GtkWidget *real_pref_radiobutton_new(GtkWidget *parent_box, GtkWidget *si
 		}
 	else
 		{
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 		button = gtk_toggle_button_new_with_label(text);
 		gtk_toggle_button_set_group(button, group);
 #else
@@ -423,7 +431,7 @@ GtkWidget *pref_radiobutton_new_mnemonic_unused(GtkWidget *parent_box, GtkWidget
 
 static void pref_radiobutton_int_cb_unused(GtkWidget *widget, gpointer data)
 {
-	gboolean *result = static_cast<gboolean *>(data);
+	auto *result = static_cast<gboolean *>(data);
 
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
 		{
@@ -806,7 +814,7 @@ static void date_selection_popup_hide(DateSelection *ds)
 
 	gtk_widget_hide(ds->window);
 
-	g_object_unref(ds->window);
+	gq_gtk_widget_destroy(ds->window);
 	ds->window = nullptr;
 	ds->calendar = nullptr;
 
@@ -824,9 +832,12 @@ static gboolean date_selection_popup_release_cb(GtkWidget *, GdkEventButton *, g
 static gboolean date_selection_popup_press_cb(GtkWidget *, GdkEventButton *event, gpointer data)
 {
 	auto ds = static_cast<DateSelection *>(data);
-	gint x, y;
-	gint w, h;
-	gint xr, yr;
+	gint x;
+	gint y;
+	gint w;
+	gint h;
+	gint xr;
+	gint yr;
 	GdkWindow *window;
 
 	xr = static_cast<gint>(event->x_root);
@@ -908,8 +919,10 @@ static void date_selection_doubleclick_cb(GtkWidget *, gpointer data)
 static void date_selection_popup(DateSelection *ds)
 {
 	GDateTime *date;
-	gint wx, wy;
-	gint x, y;
+	gint wx;
+	gint wy;
+	gint x;
+	gint y;
 	GtkAllocation button_allocation;
 	GtkAllocation window_allocation;
 
@@ -927,7 +940,7 @@ static void date_selection_popup(DateSelection *ds)
 	gtk_widget_show(ds->calendar);
 
 	date = date_selection_get(ds->box);
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 	gtk_calendar_select_day(GTK_CALENDAR(ds->calendar), date);
 #else
 	gtk_calendar_select_month(GTK_CALENDAR(ds->calendar), g_date_time_get_month(date), g_date_time_get_year(date));
@@ -1305,7 +1318,7 @@ gboolean pref_list_double_get_unused(const gchar *group, const gchar *key, gdoub
 
 	if (pref_list_get(group, key, PREF_LIST_MARKER_DOUBLE, &text) && text)
 		{
-		*result = g_ascii_strtod(text, NULL);
+		*result = g_ascii_strtod(text, nullptr);
 		return TRUE;
 		}
 
@@ -1381,21 +1394,22 @@ gchar *text_widget_text_pull(GtkWidget *text_widget)
 	if (GTK_IS_TEXT_VIEW(text_widget))
 		{
 		GtkTextBuffer *buffer;
-		GtkTextIter start, end;
+		GtkTextIter start;
+		GtkTextIter end;
 
 		buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_widget));
 		gtk_text_buffer_get_bounds(buffer, &start, &end);
 
 		return gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
 		}
-	else if (GTK_IS_ENTRY(text_widget))
+
+	if (GTK_IS_ENTRY(text_widget))
 		{
 		return g_strdup(gq_gtk_entry_get_text(GTK_ENTRY(text_widget)));
 		}
-	else
-		{
-		return nullptr;
-		}
+
+	return nullptr;
+	
 
 }
 
@@ -1404,7 +1418,8 @@ gchar *text_widget_text_pull_selected(GtkWidget *text_widget)
 	if (GTK_IS_TEXT_VIEW(text_widget))
 		{
 		GtkTextBuffer *buffer;
-		GtkTextIter start, end;
+		GtkTextIter start;
+		GtkTextIter end;
 
 		buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_widget));
 		gtk_text_buffer_get_bounds(buffer, &start, &end);
@@ -1417,14 +1432,14 @@ gchar *text_widget_text_pull_selected(GtkWidget *text_widget)
 
 		return gtk_text_buffer_get_text(buffer, &start, &end, FALSE);
 		}
-	else if (GTK_IS_ENTRY(text_widget))
+
+	if (GTK_IS_ENTRY(text_widget))
 		{
 		return g_strdup(gq_gtk_entry_get_text(GTK_ENTRY(text_widget)));
 		}
-	else
-		{
-		return nullptr;
-		}
+
+	return nullptr;
+	
 }
 
 static gint simple_sort_cb(gconstpointer a, gconstpointer b)
