@@ -19,30 +19,42 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "ui-pathsel.h"
+
 #include <cstring>
 
 #include <dirent.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 
-#include "main.h"
-#include "ui-pathsel.h"
+#include <gdk/gdk.h>
+#include <glib-object.h>
 
+#include "compat.h"
+#include "debug.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "misc.h"
+#include "options.h"
+#include "typedefs.h"
 #include "ui-bookmark.h"
 #include "ui-fileops.h"
 #include "ui-menu.h"
 #include "ui-misc.h"
 #include "ui-tabcomp.h"
 #include "ui-tree-edit.h"
+#include "ui-utildlg.h"
 #include "uri-utils.h"
 #include "utilops.h"
 
 
-#define DEST_WIDTH 250
-#define DEST_HEIGHT 210
+enum {
+	DEST_WIDTH = 250,
+	DEST_HEIGHT = 210
+};
 
-#define RENAME_PRESS_DELAY 333	/* 1/3 second, to allow double clicks */
+enum {
+	RENAME_PRESS_DELAY = 333	/* 1/3 second, to allow double clicks */
+};
 
 #define PATH_SEL_USE_HEADINGS FALSE
 
@@ -319,7 +331,9 @@ static GtkTargetEntry dest_drag_types[] = {
 	{ const_cast<gchar *>("text/uri-list"), 0, TARGET_URI_LIST },
 	{ const_cast<gchar *>("text/plain"),    0, TARGET_TEXT_PLAIN }
 };
-#define dest_drag_types_n 2
+enum {
+	dest_drag_types_n = 2
+};
 
 
 static void dest_dnd_set_data(GtkWidget *view, GdkDragContext *,
@@ -525,7 +539,7 @@ static void dest_view_delete(Dest_Data *dd, GtkTreeView *view)
 				    dd->entry, TRUE,
 				    dest_view_delete_dlg_cancel, dl);
 
-	generic_dialog_add_button(dd->gd, GQ_ICON_DELETE, "Delete", dest_view_delete_dlg_ok_cb, TRUE);
+	generic_dialog_add_button(dd->gd, GQ_ICON_DELETE, _("Delete"), dest_view_delete_dlg_ok_cb, TRUE);
 
 	text = g_strdup_printf(_("About to delete the file:\n %s"), path);
 	generic_dialog_add_message(dd->gd, GQ_ICON_DIALOG_QUESTION,
@@ -638,7 +652,8 @@ static gboolean dest_press_cb(GtkWidget *view, GdkEventButton *event, gpointer d
 	auto dd = static_cast<Dest_Data *>(data);
 	GtkTreePath *tpath;
 	GtkTreeViewColumn *column;
-	gint cell_x, cell_y;
+	gint cell_x;
+	gint cell_y;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	GtkTreeSelection *selection;
@@ -1210,12 +1225,12 @@ GtkWidget *path_selection_new_with_files(GtkWidget *entry, const gchar *path,
 #pragma GCC diagnostic ignored "-Wunused-function"
 GtkWidget *path_selection_new_unused(const gchar *path, GtkWidget *entry)
 {
-	return path_selection_new_with_files(entry, path, NULL, NULL);
+	return path_selection_new_with_files(entry, path, nullptr, nullptr);
 }
 
 void path_selection_sync_to_entry_unused(GtkWidget *entry)
 {
-	Dest_Data *dd = static_cast<Dest_Data *>(g_object_get_data(G_OBJECT(entry), "destination_data"));
+	auto *dd = static_cast<Dest_Data *>(g_object_get_data(G_OBJECT(entry), "destination_data"));
 	const gchar *path;
 
 	if (!dd) return;
