@@ -22,6 +22,9 @@
 #ifndef UI_TREE_EDIT_H
 #define UI_TREE_EDIT_H
 
+#include <gdk/gdk.h>
+#include <glib.h>
+#include <gtk/gtk.h>
 
 struct TreeEditData
 {
