@@ -19,22 +19,37 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "utilops.h"
 
+#include <unistd.h>
+
+#include <cstring>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdk.h>
+#include <glib-object.h>
+
+#include <config.h>
+
 #include "cache.h"
+#include "compat.h"
+#include "debug.h"
 #include "editors.h"
 #include "exif.h"
 #include "filedata.h"
 #include "filefilter.h"
 #include "image.h"
+#include "intl.h"
+#include "main-defines.h"
 #include "metadata.h"
 #include "misc.h"
+#include "options.h"
 #include "thumb-standard.h"
 #include "trash.h"
 #include "ui-bookmark.h"
 #include "ui-fileops.h"
 #include "ui-misc.h"
+#include "ui-utildlg.h"
 
 namespace
 {
@@ -46,9 +61,9 @@ struct PixmapErrors
 	GdkPixbuf *apply;
 };
 
-GdkPixbuf *file_util_get_error_icon(FileData *fd, GList *list, GtkWidget *widget)
+GdkPixbuf *file_util_get_error_icon(FileData *fd, GList *list, GtkWidget *)
 {
-	static PixmapErrors pe = [widget]() -> PixmapErrors
+	static PixmapErrors pe = []() -> PixmapErrors
 	{
 		GtkIconTheme *icon_theme = gtk_icon_theme_get_default();
 
@@ -81,7 +96,9 @@ GdkPixbuf *file_util_get_error_icon(FileData *fd, GList *list, GtkWidget *widget
 
 }
 
-#define DIALOG_WIDTH 750
+enum {
+	DIALOG_WIDTH = 750
+};
 
 enum ClipboardDestination {
 	CLIPBOARD_TEXT_PLAIN	= 0,
@@ -111,8 +128,10 @@ struct ClipboardData
  *--------------------------------------------------------------------------
  */
 
-#define DIALOG_DEF_IMAGE_DIM_X 150
-#define DIALOG_DEF_IMAGE_DIM_Y 100
+enum {
+	DIALOG_DEF_IMAGE_DIM_X = 150,
+	DIALOG_DEF_IMAGE_DIM_Y = 100
+};
 
 static void generic_dialog_add_image(GenericDialog *gd, GtkWidget *box,
 				     FileData *fd1, const gchar *header1,
@@ -226,7 +245,7 @@ static void generic_dialog_add_image(GenericDialog *gd, GtkWidget *box,
  * @param data
  * @returns
  *
- * \image html file_util_gen_dlg.png "Typical implementation" width=200
+ * \image html file_util_gen_dlg.png 'Typical implementation' width=200
  */
 GenericDialog *file_util_gen_dlg(const gchar *title,
 				 const gchar *role,
@@ -253,7 +272,7 @@ GenericDialog *file_util_gen_dlg(const gchar *title,
  * @param data
  * @returns
  *
- * \image html file_util_file_dlg.png "Typical implementation including optional filter, buttons and path widgets" width=300
+ * \image html file_util_file_dlg.png 'Typical implementation including optional filter, buttons and path widgets' width=300
  */
 FileDialog *file_util_file_dlg(const gchar *title,
 			       const gchar *role,
@@ -477,11 +496,15 @@ static void generic_dialog_image_set(UtilityData *ud, FileData *fd)
 
 static gboolean file_util_write_metadata_first(UtilityType type, UtilityPhase phase, GList *flist, const gchar *dest_path, const gchar *editor_key, GtkWidget *parent);
 
-#define UTILITY_LIST_MIN_WIDTH  250
-#define UTILITY_LIST_MIN_HEIGHT 150
+enum {
+	UTILITY_LIST_MIN_WIDTH =  250,
+	UTILITY_LIST_MIN_HEIGHT = 150
+};
 
 /* thumbnail spec has a max depth of 4 (.thumb??/fail/appname/??.png) */
-#define UTILITY_DELETE_MAX_DEPTH 5
+enum {
+	UTILITY_DELETE_MAX_DEPTH = 5
+};
 
 static UtilityData *file_util_data_new(UtilityType type)
 {
@@ -1318,8 +1341,10 @@ static void file_util_rename_preview_update(UtilityData *ud)
 {
 	GtkTreeModel *store;
 	GtkTreeSelection *selection;
-	GtkTreeIter iter, iter_selected;
-	GtkTreePath *path_iter, *path_selected;
+	GtkTreeIter iter;
+	GtkTreeIter iter_selected;
+	GtkTreePath *path_iter;
+	GtkTreePath *path_selected;
 	const gchar *front;
 	const gchar *end;
 	const gchar *format;
@@ -1749,7 +1774,7 @@ static void file_util_dialog_init_source_dest(UtilityData *ud, gboolean second_i
 
 	if (second_image)
 		{
-		generic_dialog_add_image(ud->gd, box, nullptr, "Source", TRUE, nullptr, "Destination", TRUE);
+		generic_dialog_add_image(ud->gd, box, nullptr, _("Source"), TRUE, nullptr, _("Destination"), TRUE);
 		}
 	else
 		{
@@ -1980,8 +2005,7 @@ static void file_util_warn_op_in_progress(const gchar *title)
 
 static void file_util_details_dialog_close_cb(GtkWidget *, gpointer data)
 {
-	g_object_unref(GTK_WIDGET(data));
-
+	gq_gtk_widget_destroy(GTK_WIDGET(data));
 }
 
 static void file_util_details_dialog_destroy_cb(GtkWidget *widget, gpointer data)
@@ -2705,8 +2729,7 @@ static void file_util_delete_dir_full(FileData *fd, GtkWidget *parent, UtilityPh
 		ud->messages.title = _("Delete folder");
 		ud->messages.question = _("Delete symbolic link?");
 		ud->messages.desc_flist = "";
-		ud->messages.desc_source_fd = _("This will delete the symbolic link.\n"
-						"The folder this link points to will not be deleted.");
+		ud->messages.desc_source_fd = _("This will delete the symbolic link.\nThe folder this link points to will not be deleted.");
 		ud->messages.fail = _("Link deletion failed");
 
 		file_util_dialog_run(ud);
@@ -2717,8 +2740,7 @@ static void file_util_delete_dir_full(FileData *fd, GtkWidget *parent, UtilityPh
 		{
 		gchar *text;
 
-		text = g_strdup_printf(_("Unable to remove folder %s\n"
-					 "Permissions do not allow writing to the folder."), fd->path);
+		text = g_strdup_printf(_("Unable to remove folder %s\nPermissions do not allow writing to the folder."), fd->path);
 		file_util_warning_dialog(_("Delete failed"), text, GQ_ICON_DIALOG_ERROR, parent);
 		g_free(text);
 
@@ -2747,8 +2769,7 @@ static void file_util_delete_dir_full(FileData *fd, GtkWidget *parent, UtilityPh
 					parent, TRUE, nullptr, nullptr);
 		generic_dialog_add_button(gd, GQ_ICON_CLOSE, _("Close"), nullptr, TRUE);
 
-		text = g_strdup_printf(_("Unable to delete the folder:\n\n%s\n\n"
-					 "This folder contains subfolders which must be moved before it can be deleted."),
+		text = g_strdup_printf(_("Unable to delete the folder:\n\n%s\n\nThis folder contains subfolders which must be moved before it can be deleted."),
 					fd->path);
 		box = generic_dialog_add_message(gd, GQ_ICON_DIALOG_WARNING,
 						 _("Folder contains subfolders"),
@@ -2778,8 +2799,7 @@ static void file_util_delete_dir_full(FileData *fd, GtkWidget *parent, UtilityPh
 		ud->messages.title = _("Delete folder");
 		ud->messages.question = _("Delete folder?");
 		ud->messages.desc_flist = _("The folder contains these files:");
-		ud->messages.desc_source_fd = _("This will delete the folder.\n"
-						"The contents of this folder will also be deleted.");
+		ud->messages.desc_source_fd = _("This will delete the folder.\nThe contents of this folder will also be deleted.");
 		ud->messages.fail = _("File deletion failed");
 
 		if (!file_util_delete_dir_prepare(ud, flist, dlist))
@@ -3119,7 +3139,7 @@ void file_util_start_editor_from_filelist(const gchar *key, GList *list, const g
 #pragma GCC diagnostic ignored "-Wunused-function"
 void file_util_start_filter_from_file_unused(const gchar *key, FileData *fd, const gchar *dest_path, GtkWidget *parent)
 {
-	file_util_start_editor_full(key, fd, NULL, dest_path, NULL, parent, UTILITY_PHASE_ENTERING);
+	file_util_start_editor_full(key, fd, nullptr, dest_path, nullptr, parent, UTILITY_PHASE_ENTERING);
 }
 #pragma GCC diagnostic pop
 
@@ -3152,7 +3172,7 @@ void file_util_rename_dir(FileData *source_fd, const gchar *new_path, GtkWidget
  *
  *
  */
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 static void clipboard_get_func(GtkClipboard *clipboard, GtkSelectionData *selection_data, guint info, gpointer data)
 {
 /* @FIXME GTK4 stub */
