@@ -18,22 +18,35 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include "main.h"
 #include "view-dir.h"
 
+#include <sys/stat.h>
+#include <unistd.h>
+
+#include <cstring>
+
+#include <glib-object.h>
+
+#include <config.h>
+
+#include "compat.h"
+#include "debug.h"
 #include "dnd.h"
 #include "dupe.h"
 #include "editors.h"
 #include "filedata.h"
-#include "layout.h"
+#include "intl.h"
 #include "layout-image.h"
+#include "layout.h"
+#include "main-defines.h"
 #include "menu.h"
+#include "options.h"
 #include "ui-fileops.h"
-#include "ui-tree-edit.h"
 #include "ui-menu.h"
 #include "ui-misc.h"
-#include "utilops.h"
+#include "ui-tree-edit.h"
 #include "uri-utils.h"
+#include "utilops.h"
 #include "view-dir-list.h"
 #include "view-dir-tree.h"
 
@@ -130,7 +143,7 @@ static void vd_destroy_cb(GtkWidget *widget, gpointer data)
 		{
 		g_signal_handlers_disconnect_matched(G_OBJECT(vd->popup), G_SIGNAL_MATCH_DATA,
 						     0, 0, nullptr, nullptr, vd);
-		g_object_unref(vd->popup);
+		gq_gtk_widget_destroy(vd->popup);
 		}
 
 	switch (vd->type)
@@ -236,7 +249,7 @@ void vd_refresh(ViewDir *vd)
 #pragma GCC diagnostic ignored "-Wunused-function"
 const gchar *vd_row_get_path_unused(ViewDir *vd, gint row)
 {
-	const gchar *ret = NULL;
+	const gchar *ret = nullptr;
 
 	switch (vd->type)
 	{
@@ -1042,8 +1055,10 @@ static gboolean vd_auto_scroll_idle_cb(gpointer data)
 	if (vd->drop_fd)
 		{
 		GdkWindow *window;
-		gint x, y;
-		gint w, h;
+		gint x;
+		gint y;
+		gint w;
+		gint h;
 
 		window = gtk_widget_get_window(vd->view);
 		seat = gdk_display_get_default_seat(gdk_window_get_display(window));
@@ -1085,10 +1100,8 @@ static gboolean vd_dnd_drop_motion(GtkWidget *, GdkDragContext *context, gint x,
 		gdk_drag_status(context, GDK_ACTION_DEFAULT, time);
 		return TRUE;
 		}
-	else
-		{
-		gdk_drag_status(context, gdk_drag_context_get_suggested_action(context), time);
-		}
+
+	gdk_drag_status(context, gdk_drag_context_get_suggested_action(context), time);
 
 	vd_dnd_drop_update(vd, x, y);
 
@@ -1143,11 +1156,12 @@ void vd_dnd_init(ViewDir *vd)
 #pragma GCC diagnostic ignored "-Wunused-function"
 void vd_menu_position_cb_unused(GtkMenu *menu, gint *x, gint *y, gboolean *, gpointer data)
 {
-	ViewDir *vd = static_cast<ViewDir *>(data);
+	auto *vd = static_cast<ViewDir *>(data);
 	GtkTreeModel *store;
 	GtkTreeIter iter;
 	GtkTreePath *tpath;
-	gint cw, ch;
+	gint cw;
+	gint ch;
 
 	if (!vd_find_row(vd, vd->click_fd, &iter)) return;
 	store = gtk_tree_view_get_model(GTK_TREE_VIEW(vd->view));
@@ -1170,10 +1184,9 @@ void vd_activate_cb(GtkTreeView *tview, GtkTreePath *tpath, GtkTreeViewColumn *,
 static GdkRGBA *vd_color_shifted(GtkWidget *widget)
 {
 	static GdkRGBA color;
-	static GdkRGBA color_style;
 	static GtkWidget *done = nullptr;
 
-#ifdef HAVE_GTK4
+#if HAVE_GTK4
 /* @FIXME GTK4 no background color */
 #else
 	if (done != widget)
@@ -1181,9 +1194,7 @@ static GdkRGBA *vd_color_shifted(GtkWidget *widget)
 		GtkStyleContext *style_context;
 
 		style_context = gtk_widget_get_style_context(widget);
-		gtk_style_context_get_background_color(style_context, GTK_STATE_FLAG_NORMAL, &color_style);
-
-		memcpy(&color, &color_style, sizeof(color_style));
+		gtk_style_context_get_background_color(style_context, GTK_STATE_FLAG_NORMAL, &color);
 
 		shift_color(&color, -1, 0);
 		done = widget;
